# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/feegrant/v1beta1/feegrant.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cosmos/feegrant/v1beta1/feegrant.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&cosmos/feegrant/v1beta1/feegrant.proto\x12\x17\x63osmos.feegrant.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\"\xbb\x01\n\x0e\x42\x61sicAllowance\x12`\n\x0bspend_limit\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12\x34\n\nexpiration\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\x90\xdf\x1f\x01:\x11\xca\xb4-\rFeeAllowanceI\"\xa5\x03\n\x11PeriodicAllowance\x12<\n\x05\x62\x61sic\x18\x01 \x01(\x0b\x32\'.cosmos.feegrant.v1beta1.BasicAllowanceB\x04\xc8\xde\x1f\x00\x12\x33\n\x06period\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xc8\xde\x1f\x00\x98\xdf\x1f\x01\x12g\n\x12period_spend_limit\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12\x65\n\x10period_can_spend\x18\x04 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12:\n\x0cperiod_reset\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01:\x11\xca\xb4-\rFeeAllowanceI\"\x82\x01\n\x13\x41llowedMsgAllowance\x12:\n\tallowance\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyB\x11\xca\xb4-\rFeeAllowanceI\x12\x18\n\x10\x61llowed_messages\x18\x02 \x03(\t:\x15\x88\xa0\x1f\x00\xca\xb4-\rFeeAllowanceI\"e\n\x05Grant\x12\x0f\n\x07granter\x18\x01 \x01(\t\x12\x0f\n\x07grantee\x18\x02 \x01(\t\x12:\n\tallowance\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyB\x11\xca\xb4-\rFeeAllowanceIB)Z\'github.com/cosmos/cosmos-sdk/x/feegrantb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.feegrant.v1beta1.feegrant_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\'github.com/cosmos/cosmos-sdk/x/feegrant'
  _globals['_BASICALLOWANCE'].fields_by_name['spend_limit']._loaded_options = None
  _globals['_BASICALLOWANCE'].fields_by_name['spend_limit']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _globals['_BASICALLOWANCE'].fields_by_name['expiration']._loaded_options = None
  _globals['_BASICALLOWANCE'].fields_by_name['expiration']._serialized_options = b'\220\337\037\001'
  _globals['_BASICALLOWANCE']._loaded_options = None
  _globals['_BASICALLOWANCE']._serialized_options = b'\312\264-\rFeeAllowanceI'
  _globals['_PERIODICALLOWANCE'].fields_by_name['basic']._loaded_options = None
  _globals['_PERIODICALLOWANCE'].fields_by_name['basic']._serialized_options = b'\310\336\037\000'
  _globals['_PERIODICALLOWANCE'].fields_by_name['period']._loaded_options = None
  _globals['_PERIODICALLOWANCE'].fields_by_name['period']._serialized_options = b'\310\336\037\000\230\337\037\001'
  _globals['_PERIODICALLOWANCE'].fields_by_name['period_spend_limit']._loaded_options = None
  _globals['_PERIODICALLOWANCE'].fields_by_name['period_spend_limit']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _globals['_PERIODICALLOWANCE'].fields_by_name['period_can_spend']._loaded_options = None
  _globals['_PERIODICALLOWANCE'].fields_by_name['period_can_spend']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _globals['_PERIODICALLOWANCE'].fields_by_name['period_reset']._loaded_options = None
  _globals['_PERIODICALLOWANCE'].fields_by_name['period_reset']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_PERIODICALLOWANCE']._loaded_options = None
  _globals['_PERIODICALLOWANCE']._serialized_options = b'\312\264-\rFeeAllowanceI'
  _globals['_ALLOWEDMSGALLOWANCE'].fields_by_name['allowance']._loaded_options = None
  _globals['_ALLOWEDMSGALLOWANCE'].fields_by_name['allowance']._serialized_options = b'\312\264-\rFeeAllowanceI'
  _globals['_ALLOWEDMSGALLOWANCE']._loaded_options = None
  _globals['_ALLOWEDMSGALLOWANCE']._serialized_options = b'\210\240\037\000\312\264-\rFeeAllowanceI'
  _globals['_GRANT'].fields_by_name['allowance']._loaded_options = None
  _globals['_GRANT'].fields_by_name['allowance']._serialized_options = b'\312\264-\rFeeAllowanceI'
  _globals['_BASICALLOWANCE']._serialized_start=241
  _globals['_BASICALLOWANCE']._serialized_end=428
  _globals['_PERIODICALLOWANCE']._serialized_start=431
  _globals['_PERIODICALLOWANCE']._serialized_end=852
  _globals['_ALLOWEDMSGALLOWANCE']._serialized_start=855
  _globals['_ALLOWEDMSGALLOWANCE']._serialized_end=985
  _globals['_GRANT']._serialized_start=987
  _globals['_GRANT']._serialized_end=1088
# @@protoc_insertion_point(module_scope)



from cometbft.types.v2 import types_pb2 as _types_pb2
from cometbft.types.v2 import block_pb2 as _block_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetByHeightRequest(_message.Message):
    __slots__ = ("height",)
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    height: int
    def __init__(self, height: _Optional[int] = ...) -> None: ...

class GetByHeightResponse(_message.Message):
    __slots__ = ("block_id", "block")
    BLOCK_ID_FIELD_NUMBER: _ClassVar[int]
    BLOCK_FIELD_NUMBER: _ClassVar[int]
    block_id: _types_pb2.BlockID
    block: _block_pb2.Block
    def __init__(self, block_id: _Optional[_Union[_types_pb2.BlockID, _Mapping]] = ..., block: _Optional[_Union[_block_pb2.Block, _Mapping]] = ...) -> None: ...

class GetLatestHeightRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetLatestHeightResponse(_message.Message):
    __slots__ = ("height",)
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    height: int
    def __init__(self, height: _Optional[int] = ...) -> None: ...



from gogoproto import gogo_pb2 as _gogo_pb2
from cosmwasm.wasm.v1 import types_pb2 as _types_pb2
from cosmwasm.wasm.v1 import tx_pb2 as _tx_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GenesisState(_message.Message):
    __slots__ = ("params", "codes", "contracts", "sequences", "gen_msgs")
    class GenMsgs(_message.Message):
        __slots__ = ("store_code", "instantiate_contract", "execute_contract")
        STORE_CODE_FIELD_NUMBER: _ClassVar[int]
        INSTANTIATE_CONTRACT_FIELD_NUMBER: _ClassVar[int]
        EXECUTE_CONTRACT_FIELD_NUMBER: _ClassVar[int]
        store_code: _tx_pb2.MsgStoreCode
        instantiate_contract: _tx_pb2.MsgInstantiateContract
        execute_contract: _tx_pb2.MsgExecuteContract
        def __init__(self, store_code: _Optional[_Union[_tx_pb2.MsgStoreCode, _Mapping]] = ..., instantiate_contract: _Optional[_Union[_tx_pb2.MsgInstantiateContract, _Mapping]] = ..., execute_contract: _Optional[_Union[_tx_pb2.MsgExecuteContract, _Mapping]] = ...) -> None: ...
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    CODES_FIELD_NUMBER: _ClassVar[int]
    CONTRACTS_FIELD_NUMBER: _ClassVar[int]
    SEQUENCES_FIELD_NUMBER: _ClassVar[int]
    GEN_MSGS_FIELD_NUMBER: _ClassVar[int]
    params: _types_pb2.Params
    codes: _containers.RepeatedCompositeFieldContainer[Code]
    contracts: _containers.RepeatedCompositeFieldContainer[Contract]
    sequences: _containers.RepeatedCompositeFieldContainer[Sequence]
    gen_msgs: _containers.RepeatedCompositeFieldContainer[GenesisState.GenMsgs]
    def __init__(self, params: _Optional[_Union[_types_pb2.Params, _Mapping]] = ..., codes: _Optional[_Iterable[_Union[Code, _Mapping]]] = ..., contracts: _Optional[_Iterable[_Union[Contract, _Mapping]]] = ..., sequences: _Optional[_Iterable[_Union[Sequence, _Mapping]]] = ..., gen_msgs: _Optional[_Iterable[_Union[GenesisState.GenMsgs, _Mapping]]] = ...) -> None: ...

class Code(_message.Message):
    __slots__ = ("code_id", "code_info", "code_bytes", "pinned")
    CODE_ID_FIELD_NUMBER: _ClassVar[int]
    CODE_INFO_FIELD_NUMBER: _ClassVar[int]
    CODE_BYTES_FIELD_NUMBER: _ClassVar[int]
    PINNED_FIELD_NUMBER: _ClassVar[int]
    code_id: int
    code_info: _types_pb2.CodeInfo
    code_bytes: bytes
    pinned: bool
    def __init__(self, code_id: _Optional[int] = ..., code_info: _Optional[_Union[_types_pb2.CodeInfo, _Mapping]] = ..., code_bytes: _Optional[bytes] = ..., pinned: bool = ...) -> None: ...

class Contract(_message.Message):
    __slots__ = ("contract_address", "contract_info", "contract_state")
    CONTRACT_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    CONTRACT_INFO_FIELD_NUMBER: _ClassVar[int]
    CONTRACT_STATE_FIELD_NUMBER: _ClassVar[int]
    contract_address: str
    contract_info: _types_pb2.ContractInfo
    contract_state: _containers.RepeatedCompositeFieldContainer[_types_pb2.Model]
    def __init__(self, contract_address: _Optional[str] = ..., contract_info: _Optional[_Union[_types_pb2.ContractInfo, _Mapping]] = ..., contract_state: _Optional[_Iterable[_Union[_types_pb2.Model, _Mapping]]] = ...) -> None: ...

class Sequence(_message.Message):
    __slots__ = ("id_key", "value")
    ID_KEY_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    id_key: bytes
    value: int
    def __init__(self, id_key: _Optional[bytes] = ..., value: _Optional[int] = ...) -> None: ...



from google.protobuf.json_format import Parse

from neurionpy.common.rest_client import RestClient
from neurionpy.params.interface import Params
from neurionpy.protos.cosmos.params.v1beta1.query_pb2 import (
    QueryParamsRequest,
    QueryParamsResponse,
)


class ParamsRestClient(Params):
    """Params REST client."""

    API_URL = "/cosmos/params/v1beta1"

    def __init__(self, rest_api: RestClient) -> None:
        """
        Initialize.

        :param rest_api: RestClient api
        """
        self._rest_api = rest_api

    def Params(self, request: QueryParamsRequest) -> QueryParamsResponse:
        """
        Params queries a specific Cosmos SDK parameter.

        :param request: QueryParamsRequest
        :return: QueryParamsResponse
        """
        json_response = self._rest_api.get(f"{self.API_URL}/params", request)
        return Parse(json_response, QueryParamsResponse())



from abc import ABC, abstractmethod

from neurionpy.protos.ibc.applications.transfer.v1.query_pb2 import (
    QueryDenomTraceRequest,
    QueryDenomTraceResponse,
    QueryDenomTracesRequest,
    QueryDenomTracesResponse,
    QueryParamsRequest,
    QueryParamsResponse,
)


class IBCApplicationsTransfer(ABC):
    """IBC Applications Transfer abstract class."""

    @abstractmethod
    def DenomTrace(self, request: QueryDenomTraceRequest) -> QueryDenomTraceResponse:
        """
        DenomTrace queries a denomination trace information.

        :param request: QueryDenomTraceRequest
        :return: QueryDenomTraceResponse
        """

    @abstractmethod
    def DenomTraces(self, request: QueryDenomTracesRequest) -> QueryDenomTracesResponse:
        """
        DenomTraces queries all denomination traces.

        :param request: QueryDenomTracesRequest
        :return: QueryDenomTracesResponse
        """

    @abstractmethod
    def Params(self, request: QueryParamsRequest) -> QueryParamsResponse:
        """
        Params queries all parameters of the ibc-transfer module.

        :param request: QueryParamsRequest
        :return: QueryParamsResponse
        """



from cometbft.abci.v1beta1 import types_pb2 as _types_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class RequestPing(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class RequestBroadcastTx(_message.Message):
    __slots__ = ("tx",)
    TX_FIELD_NUMBER: _ClassVar[int]
    tx: bytes
    def __init__(self, tx: _Optional[bytes] = ...) -> None: ...

class ResponsePing(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ResponseBroadcastTx(_message.Message):
    __slots__ = ("check_tx", "deliver_tx")
    CHECK_TX_FIELD_NUMBER: _ClassVar[int]
    DELIVER_TX_FIELD_NUMBER: _ClassVar[int]
    check_tx: _types_pb2.ResponseCheckTx
    deliver_tx: _types_pb2.ResponseDeliverTx
    def __init__(self, check_tx: _Optional[_Union[_types_pb2.ResponseCheckTx, _Mapping]] = ..., deliver_tx: _Optional[_Union[_types_pb2.ResponseDeliverTx, _Mapping]] = ...) -> None: ...



from amino import amino_pb2 as _amino_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Params(_message.Message):
    __slots__ = ("admin_address", "min_task_duration_in_days", "min_task_reward", "min_task_trainer_stake", "min_task_scorer_stake", "submission_cooling_off_period_in_seconds", "min_report_plagiarism_deposit", "min_dispute_score_deposit", "min_creator_stake", "creator_application_fee", "dispute_score_reward", "min_task_training_in_days", "min_task_final_submission_in_days", "min_task_final_dispute_in_days", "trainers_reward_percentage", "scorer_reward_percentage", "stakers_reward_percentage", "trainer_first_place_reward_percentage", "trainer_second_place_reward_percentage", "trainer_third_place_reward_percentage", "trainers_number_to_be_rewarded_except_first_three")
    ADMIN_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    MIN_TASK_DURATION_IN_DAYS_FIELD_NUMBER: _ClassVar[int]
    MIN_TASK_REWARD_FIELD_NUMBER: _ClassVar[int]
    MIN_TASK_TRAINER_STAKE_FIELD_NUMBER: _ClassVar[int]
    MIN_TASK_SCORER_STAKE_FIELD_NUMBER: _ClassVar[int]
    SUBMISSION_COOLING_OFF_PERIOD_IN_SECONDS_FIELD_NUMBER: _ClassVar[int]
    MIN_REPORT_PLAGIARISM_DEPOSIT_FIELD_NUMBER: _ClassVar[int]
    MIN_DISPUTE_SCORE_DEPOSIT_FIELD_NUMBER: _ClassVar[int]
    MIN_CREATOR_STAKE_FIELD_NUMBER: _ClassVar[int]
    CREATOR_APPLICATION_FEE_FIELD_NUMBER: _ClassVar[int]
    DISPUTE_SCORE_REWARD_FIELD_NUMBER: _ClassVar[int]
    MIN_TASK_TRAINING_IN_DAYS_FIELD_NUMBER: _ClassVar[int]
    MIN_TASK_FINAL_SUBMISSION_IN_DAYS_FIELD_NUMBER: _ClassVar[int]
    MIN_TASK_FINAL_DISPUTE_IN_DAYS_FIELD_NUMBER: _ClassVar[int]
    TRAINERS_REWARD_PERCENTAGE_FIELD_NUMBER: _ClassVar[int]
    SCORER_REWARD_PERCENTAGE_FIELD_NUMBER: _ClassVar[int]
    STAKERS_REWARD_PERCENTAGE_FIELD_NUMBER: _ClassVar[int]
    TRAINER_FIRST_PLACE_REWARD_PERCENTAGE_FIELD_NUMBER: _ClassVar[int]
    TRAINER_SECOND_PLACE_REWARD_PERCENTAGE_FIELD_NUMBER: _ClassVar[int]
    TRAINER_THIRD_PLACE_REWARD_PERCENTAGE_FIELD_NUMBER: _ClassVar[int]
    TRAINERS_NUMBER_TO_BE_REWARDED_EXCEPT_FIRST_THREE_FIELD_NUMBER: _ClassVar[int]
    admin_address: str
    min_task_duration_in_days: int
    min_task_reward: int
    min_task_trainer_stake: int
    min_task_scorer_stake: int
    submission_cooling_off_period_in_seconds: int
    min_report_plagiarism_deposit: int
    min_dispute_score_deposit: int
    min_creator_stake: int
    creator_application_fee: int
    dispute_score_reward: int
    min_task_training_in_days: int
    min_task_final_submission_in_days: int
    min_task_final_dispute_in_days: int
    trainers_reward_percentage: int
    scorer_reward_percentage: int
    stakers_reward_percentage: int
    trainer_first_place_reward_percentage: int
    trainer_second_place_reward_percentage: int
    trainer_third_place_reward_percentage: int
    trainers_number_to_be_rewarded_except_first_three: int
    def __init__(self, admin_address: _Optional[str] = ..., min_task_duration_in_days: _Optional[int] = ..., min_task_reward: _Optional[int] = ..., min_task_trainer_stake: _Optional[int] = ..., min_task_scorer_stake: _Optional[int] = ..., submission_cooling_off_period_in_seconds: _Optional[int] = ..., min_report_plagiarism_deposit: _Optional[int] = ..., min_dispute_score_deposit: _Optional[int] = ..., min_creator_stake: _Optional[int] = ..., creator_application_fee: _Optional[int] = ..., dispute_score_reward: _Optional[int] = ..., min_task_training_in_days: _Optional[int] = ..., min_task_final_submission_in_days: _Optional[int] = ..., min_task_final_dispute_in_days: _Optional[int] = ..., trainers_reward_percentage: _Optional[int] = ..., scorer_reward_percentage: _Optional[int] = ..., stakers_reward_percentage: _Optional[int] = ..., trainer_first_place_reward_percentage: _Optional[int] = ..., trainer_second_place_reward_percentage: _Optional[int] = ..., trainer_third_place_reward_percentage: _Optional[int] = ..., trainers_number_to_be_rewarded_except_first_three: _Optional[int] = ...) -> None: ...



from google.protobuf.json_format import Parse

from neurionpy.common.rest_client import RestClient
from neurionpy.protos.cosmos.upgrade.v1beta1.query_pb2 import (
    QueryAppliedPlanRequest,
    QueryAppliedPlanResponse,
    QueryCurrentPlanRequest,
    QueryCurrentPlanResponse,
)
from neurionpy.upgrade.interface import CosmosUpgrade


class CosmosUpgradeRestClient(CosmosUpgrade):
    """Cosmos Upgrade REST client."""

    API_URL = "/cosmos/upgrade/v1beta1"

    def __init__(self, rest_api: RestClient) -> None:
        """
        Initialize.

        :param rest_api: RestClient api
        """
        self._rest_api = rest_api

    def CurrentPlan(self, request: QueryCurrentPlanRequest) -> QueryCurrentPlanResponse:
        """
        CurrentPlan queries the current upgrade plan.

        :param request: QueryCurrentPlanRequest
        :return: QueryCurrentPlanResponse
        """
        json_response = self._rest_api.get(
            f"{self.API_URL}/current_plan",
        )
        return Parse(json_response, QueryCurrentPlanResponse())

    def AppliedPlan(self, request: QueryAppliedPlanRequest) -> QueryAppliedPlanResponse:
        """
        AppliedPlan queries a previously applied upgrade plan by its name.

        :param request: QueryAppliedPlanRequest
        :return: QueryAppliedPlanResponse
        """
        json_response = self._rest_api.get(
            f"{self.API_URL}/applied_plan/{request.name}", request
        )
        return Parse(json_response, QueryAppliedPlanResponse())



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: neurion/ganglion/query.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'neurion/ganglion/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from amino import amino_pb2 as amino_dot_amino__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from neurion.ganglion import params_pb2 as neurion_dot_ganglion_dot_params__pb2
from neurion.ganglion import ion_pb2 as neurion_dot_ganglion_dot_ion__pb2
from neurion.ganglion import pathway_pb2 as neurion_dot_ganglion_dot_pathway__pb2
from neurion.ganglion import pathway_user_pb2 as neurion_dot_ganglion_dot_pathway__user__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cneurion/ganglion/query.proto\x12\x10neurion.ganglion\x1a\x11\x61mino/amino.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x1dneurion/ganglion/params.proto\x1a\x1aneurion/ganglion/ion.proto\x1a\x1eneurion/ganglion/pathway.proto\x1a#neurion/ganglion/pathway_user.proto\"\x14\n\x12QueryParamsRequest\"J\n\x13QueryParamsResponse\x12\x33\n\x06params\x18\x01 \x01(\x0b\x32\x18.neurion.ganglion.ParamsB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"2\n\x1bQueryIonByIonAddressRequest\x12\x13\n\x0bion_address\x18\x01 \x01(\t\"B\n\x1cQueryIonByIonAddressResponse\x12\"\n\x03ion\x18\x01 \x01(\x0b\x32\x15.neurion.ganglion.Ion\"+\n\x18QueryIonByCreatorRequest\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\"?\n\x19QueryIonByCreatorResponse\x12\"\n\x03ion\x18\x01 \x01(\x0b\x32\x15.neurion.ganglion.Ion\"\x1b\n\x19QueryGetValidatorsRequest\"0\n\x1aQueryGetValidatorsResponse\x12\x12\n\nvalidators\x18\x01 \x03(\t\"k\n!QueryIonsByInputSchemaHashRequest\x12\x19\n\x11input_schema_hash\x18\x01 \x01(\t\x12\x0c\n\x04user\x18\x02 \x01(\t\x12\x0e\n\x06offset\x18\x03 \x01(\x04\x12\r\n\x05limit\x18\x04 \x01(\x04\"\x91\x01\n\"QueryIonsByInputSchemaHashResponse\x12.\n\x04ions\x18\x01 \x03(\x0b\x32\x15.neurion.ganglion.IonB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"$\n\x16QueryGetPathwayRequest\x12\n\n\x02id\x18\x01 \x01(\x04\"P\n\x17QueryGetPathwayResponse\x12\x35\n\x07pathway\x18\x01 \x01(\x0b\x32\x19.neurion.ganglion.PathwayB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"J\n\x18QueryListPathwaysRequest\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\x02 \x01(\x04\x12\r\n\x05limit\x18\x03 \x01(\x04\"\x90\x01\n\x19QueryListPathwaysResponse\x12\x36\n\x08pathways\x18\x01 \x03(\x0b\x32\x19.neurion.ganglion.PathwayB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"8\n\x1fQueryListIonsByAddressesRequest\x12\x15\n\rion_addresses\x18\x01 \x03(\t\"R\n QueryListIonsByAddressesResponse\x12.\n\x04ions\x18\x01 \x03(\x0b\x32\x15.neurion.ganglion.IonB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"8\n\x1cQueryUserPathwayStakeRequest\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x0c\n\x04user\x18\x02 \x01(\t\".\n\x1dQueryUserPathwayStakeResponse\x12\r\n\x05stake\x18\x01 \x01(\x04\")\n\x19QueryGetUserRewardRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\",\n\x1aQueryGetUserRewardResponse\x12\x0e\n\x06reward\x18\x01 \x01(\x04\"\x1c\n\x1aQueryGetProtocolFeeRequest\"*\n\x1bQueryGetProtocolFeeResponse\x12\x0b\n\x03\x66\x65\x65\x18\x01 \x01(\x04\"3\n\x1cQueryPathwaysUsingIonRequest\x12\x13\n\x0bion_address\x18\x01 \x01(\t\"W\n\x1dQueryPathwaysUsingIonResponse\x12\x36\n\x08pathways\x18\x01 \x03(\x0b\x32\x19.neurion.ganglion.PathwayB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\":\n\x19QueryIonsByReportsRequest\x12\x0e\n\x06offset\x18\x01 \x01(\x04\x12\r\n\x05limit\x18\x02 \x01(\x04\"p\n\x1aQueryIonsByReportsResponse\x12\x15\n\rion_addresses\x18\x01 \x03(\t\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"<\n\x1bQueryListAllPathwaysRequest\x12\x0e\n\x06offset\x18\x01 \x01(\x04\x12\r\n\x05limit\x18\x02 \x01(\x04\"\x93\x01\n\x1cQueryListAllPathwaysResponse\x12\x36\n\x08pathways\x18\x01 \x03(\x0b\x32\x19.neurion.ganglion.PathwayB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"%\n\x15QueryGetRewardRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\"(\n\x16QueryGetRewardResponse\x12\x0e\n\x06reward\x18\x01 \x01(\x04\"$\n\x14QueryGetStakeRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\"&\n\x15QueryGetStakeResponse\x12\r\n\x05stake\x18\x01 \x01(\x04\" \n\x12QueryGetIonRequest\x12\n\n\x02id\x18\x01 \x01(\x04\"D\n\x13QueryGetIonResponse\x12-\n\x03ion\x18\x01 \x01(\x0b\x32\x15.neurion.ganglion.IonB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"-\n+QueryGetPathwayUnstakeInitiatedUsersRequest\"o\n,QueryGetPathwayUnstakeInitiatedUsersResponse\x12?\n\rpathway_users\x18\x01 \x03(\x0b\x32\x1d.neurion.ganglion.PathwayUserB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"\x1d\n\x1bQueryGetStakerRewardRequest\".\n\x1cQueryGetStakerRewardResponse\x12\x0e\n\x06reward\x18\x01 \x01(\x04\"K\n\x1cQueryGetAvailableIonsRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\x02 \x01(\x04\x12\r\n\x05limit\x18\x03 \x01(\x04\"\x8c\x01\n\x1dQueryGetAvailableIonsResponse\x12.\n\x04ions\x18\x01 \x03(\x0b\x32\x15.neurion.ganglion.IonB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"T\n\x1cQueryValidateIonChainRequest\x12\x0c\n\x04ion1\x18\x01 \x01(\t\x12\x0c\n\x04ion2\x18\x02 \x01(\t\x12\x18\n\x10\x66ield_map_base64\x18\x03 \x01(\t\">\n\x1dQueryValidateIonChainResponse\x12\r\n\x05valid\x18\x01 \x01(\x08\x12\x0e\n\x06reason\x18\x02 \x01(\t\"\x1b\n\x19QueryGetAllowedIpsRequest\")\n\x1aQueryGetAllowedIpsResponse\x12\x0b\n\x03ips\x18\x01 \x03(\t2\xf2\x1c\n\x05Query\x12w\n\x06Params\x12$.neurion.ganglion.QueryParamsRequest\x1a%.neurion.ganglion.QueryParamsResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/neurion/ganglion/params\x12\xac\x01\n\x0fIonByIonAddress\x12-.neurion.ganglion.QueryIonByIonAddressRequest\x1a..neurion.ganglion.QueryIonByIonAddressResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/neurion/ganglion/ion_by_ion_address/{ion_address}\x12\x9b\x01\n\x0cIonByCreator\x12*.neurion.ganglion.QueryIonByCreatorRequest\x1a+.neurion.ganglion.QueryIonByCreatorResponse\"2\x82\xd3\xe4\x93\x02,\x12*/neurion/ganglion/ion_by_creator/{creator}\x12\x94\x01\n\rGetValidators\x12+.neurion.ganglion.QueryGetValidatorsRequest\x1a,.neurion.ganglion.QueryGetValidatorsResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /neurion/ganglion/get_validators\x12\xe3\x01\n\x15IonsByInputSchemaHash\x12\x33.neurion.ganglion.QueryIonsByInputSchemaHashRequest\x1a\x34.neurion.ganglion.QueryIonsByInputSchemaHashResponse\"_\x82\xd3\xe4\x93\x02Y\x12W/neurion/ganglion/ions_by_input_schema_hash/{input_schema_hash}/{user}/{offset}/{limit}\x12\x8d\x01\n\nGetPathway\x12(.neurion.ganglion.QueryGetPathwayRequest\x1a).neurion.ganglion.QueryGetPathwayResponse\"*\x82\xd3\xe4\x93\x02$\x12\"/neurion/ganglion/get_pathway/{id}\x12\xab\x01\n\x0cListPathways\x12*.neurion.ganglion.QueryListPathwaysRequest\x1a+.neurion.ganglion.QueryListPathwaysResponse\"B\x82\xd3\xe4\x93\x02<\x12:/neurion/ganglion/list_pathways/{creator}/{offset}/{limit}\x12\xbe\x01\n\x13ListIonsByAddresses\x12\x31.neurion.ganglion.QueryListIonsByAddressesRequest\x1a\x32.neurion.ganglion.QueryListIonsByAddressesResponse\"@\x82\xd3\xe4\x93\x02:\x12\x38/neurion/ganglion/list_ions_by_addresses/{ion_addresses}\x12\xad\x01\n\x10UserPathwayStake\x12..neurion.ganglion.QueryUserPathwayStakeRequest\x1a/.neurion.ganglion.QueryUserPathwayStakeResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/neurion/ganglion/user_pathway_stake/{id}/{user}\x12\x9c\x01\n\rGetUserReward\x12+.neurion.ganglion.QueryGetUserRewardRequest\x1a,.neurion.ganglion.QueryGetUserRewardResponse\"0\x82\xd3\xe4\x93\x02*\x12(/neurion/ganglion/get_user_reward/{user}\x12\x99\x01\n\x0eGetProtocolFee\x12,.neurion.ganglion.QueryGetProtocolFeeRequest\x1a-.neurion.ganglion.QueryGetProtocolFeeResponse\"*\x82\xd3\xe4\x93\x02$\x12\"/neurion/ganglion/get_protocol_fee\x12\xaf\x01\n\x10PathwaysUsingIon\x12..neurion.ganglion.QueryPathwaysUsingIonRequest\x1a/.neurion.ganglion.QueryPathwaysUsingIonResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/neurion/ganglion/pathways_using_ion/{ion_address}\x12\xa6\x01\n\rIonsByReports\x12+.neurion.ganglion.QueryIonsByReportsRequest\x1a,.neurion.ganglion.QueryIonsByReportsResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/neurion/ganglion/ions_by_reports/{offset}/{limit}\x12\xae\x01\n\x0fListAllPathways\x12-.neurion.ganglion.QueryListAllPathwaysRequest\x1a..neurion.ganglion.QueryListAllPathwaysResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/neurion/ganglion/list_all_pathways/{offset}/{limit}\x12\x8b\x01\n\tGetReward\x12\'.neurion.ganglion.QueryGetRewardRequest\x1a(.neurion.ganglion.QueryGetRewardResponse\"+\x82\xd3\xe4\x93\x02%\x12#/neurion/ganglion/get_reward/{user}\x12\x87\x01\n\x08GetStake\x12&.neurion.ganglion.QueryGetStakeRequest\x1a\'.neurion.ganglion.QueryGetStakeResponse\"*\x82\xd3\xe4\x93\x02$\x12\"/neurion/ganglion/get_stake/{user}\x12}\n\x06GetIon\x12$.neurion.ganglion.QueryGetIonRequest\x1a%.neurion.ganglion.QueryGetIonResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/neurion/ganglion/get_ion/{id}\x12\xdf\x01\n\x1fGetPathwayUnstakeInitiatedUsers\x12=.neurion.ganglion.QueryGetPathwayUnstakeInitiatedUsersRequest\x1a>.neurion.ganglion.QueryGetPathwayUnstakeInitiatedUsersResponse\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/neurion/ganglion/get_pathway_unstake_initiated_users\x12\x9d\x01\n\x0fGetStakerReward\x12-.neurion.ganglion.QueryGetStakerRewardRequest\x1a..neurion.ganglion.QueryGetStakerRewardResponse\"+\x82\xd3\xe4\x93\x02%\x12#/neurion/ganglion/get_staker_reward\x12\xb9\x01\n\x10GetAvailableIons\x12..neurion.ganglion.QueryGetAvailableIonsRequest\x1a/.neurion.ganglion.QueryGetAvailableIonsResponse\"D\x82\xd3\xe4\x93\x02>\x12</neurion/ganglion/get_available_ions/{user}/{offset}/{limit}\x12\xc2\x01\n\x10ValidateIonChain\x12..neurion.ganglion.QueryValidateIonChainRequest\x1a/.neurion.ganglion.QueryValidateIonChainResponse\"M\x82\xd3\xe4\x93\x02G\x12\x45/neurion/ganglion/validate_ion_chain/{ion1}/{ion2}/{field_map_base64}\x12\x95\x01\n\rGetAllowedIps\x12+.neurion.ganglion.QueryGetAllowedIpsRequest\x1a,.neurion.ganglion.QueryGetAllowedIpsResponse\")\x82\xd3\xe4\x93\x02#\x12!/neurion/ganglion/get_allowed_ipsB\x1aZ\x18neurion/x/ganglion/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'neurion.ganglion.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\030neurion/x/ganglion/types'
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._loaded_options = None
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYIONSBYINPUTSCHEMAHASHRESPONSE'].fields_by_name['ions']._loaded_options = None
  _globals['_QUERYIONSBYINPUTSCHEMAHASHRESPONSE'].fields_by_name['ions']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETPATHWAYRESPONSE'].fields_by_name['pathway']._loaded_options = None
  _globals['_QUERYGETPATHWAYRESPONSE'].fields_by_name['pathway']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYLISTPATHWAYSRESPONSE'].fields_by_name['pathways']._loaded_options = None
  _globals['_QUERYLISTPATHWAYSRESPONSE'].fields_by_name['pathways']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYLISTIONSBYADDRESSESRESPONSE'].fields_by_name['ions']._loaded_options = None
  _globals['_QUERYLISTIONSBYADDRESSESRESPONSE'].fields_by_name['ions']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYPATHWAYSUSINGIONRESPONSE'].fields_by_name['pathways']._loaded_options = None
  _globals['_QUERYPATHWAYSUSINGIONRESPONSE'].fields_by_name['pathways']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYLISTALLPATHWAYSRESPONSE'].fields_by_name['pathways']._loaded_options = None
  _globals['_QUERYLISTALLPATHWAYSRESPONSE'].fields_by_name['pathways']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETIONRESPONSE'].fields_by_name['ion']._loaded_options = None
  _globals['_QUERYGETIONRESPONSE'].fields_by_name['ion']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETPATHWAYUNSTAKEINITIATEDUSERSRESPONSE'].fields_by_name['pathway_users']._loaded_options = None
  _globals['_QUERYGETPATHWAYUNSTAKEINITIATEDUSERSRESPONSE'].fields_by_name['pathway_users']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETAVAILABLEIONSRESPONSE'].fields_by_name['ions']._loaded_options = None
  _globals['_QUERYGETAVAILABLEIONSRESPONSE'].fields_by_name['ions']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERY'].methods_by_name['Params']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Params']._serialized_options = b'\202\323\344\223\002\032\022\030/neurion/ganglion/params'
  _globals['_QUERY'].methods_by_name['IonByIonAddress']._loaded_options = None
  _globals['_QUERY'].methods_by_name['IonByIonAddress']._serialized_options = b'\202\323\344\223\0024\0222/neurion/ganglion/ion_by_ion_address/{ion_address}'
  _globals['_QUERY'].methods_by_name['IonByCreator']._loaded_options = None
  _globals['_QUERY'].methods_by_name['IonByCreator']._serialized_options = b'\202\323\344\223\002,\022*/neurion/ganglion/ion_by_creator/{creator}'
  _globals['_QUERY'].methods_by_name['GetValidators']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetValidators']._serialized_options = b'\202\323\344\223\002\"\022 /neurion/ganglion/get_validators'
  _globals['_QUERY'].methods_by_name['IonsByInputSchemaHash']._loaded_options = None
  _globals['_QUERY'].methods_by_name['IonsByInputSchemaHash']._serialized_options = b'\202\323\344\223\002Y\022W/neurion/ganglion/ions_by_input_schema_hash/{input_schema_hash}/{user}/{offset}/{limit}'
  _globals['_QUERY'].methods_by_name['GetPathway']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetPathway']._serialized_options = b'\202\323\344\223\002$\022\"/neurion/ganglion/get_pathway/{id}'
  _globals['_QUERY'].methods_by_name['ListPathways']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ListPathways']._serialized_options = b'\202\323\344\223\002<\022:/neurion/ganglion/list_pathways/{creator}/{offset}/{limit}'
  _globals['_QUERY'].methods_by_name['ListIonsByAddresses']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ListIonsByAddresses']._serialized_options = b'\202\323\344\223\002:\0228/neurion/ganglion/list_ions_by_addresses/{ion_addresses}'
  _globals['_QUERY'].methods_by_name['UserPathwayStake']._loaded_options = None
  _globals['_QUERY'].methods_by_name['UserPathwayStake']._serialized_options = b'\202\323\344\223\0022\0220/neurion/ganglion/user_pathway_stake/{id}/{user}'
  _globals['_QUERY'].methods_by_name['GetUserReward']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetUserReward']._serialized_options = b'\202\323\344\223\002*\022(/neurion/ganglion/get_user_reward/{user}'
  _globals['_QUERY'].methods_by_name['GetProtocolFee']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetProtocolFee']._serialized_options = b'\202\323\344\223\002$\022\"/neurion/ganglion/get_protocol_fee'
  _globals['_QUERY'].methods_by_name['PathwaysUsingIon']._loaded_options = None
  _globals['_QUERY'].methods_by_name['PathwaysUsingIon']._serialized_options = b'\202\323\344\223\0024\0222/neurion/ganglion/pathways_using_ion/{ion_address}'
  _globals['_QUERY'].methods_by_name['IonsByReports']._loaded_options = None
  _globals['_QUERY'].methods_by_name['IonsByReports']._serialized_options = b'\202\323\344\223\0024\0222/neurion/ganglion/ions_by_reports/{offset}/{limit}'
  _globals['_QUERY'].methods_by_name['ListAllPathways']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ListAllPathways']._serialized_options = b'\202\323\344\223\0026\0224/neurion/ganglion/list_all_pathways/{offset}/{limit}'
  _globals['_QUERY'].methods_by_name['GetReward']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetReward']._serialized_options = b'\202\323\344\223\002%\022#/neurion/ganglion/get_reward/{user}'
  _globals['_QUERY'].methods_by_name['GetStake']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetStake']._serialized_options = b'\202\323\344\223\002$\022\"/neurion/ganglion/get_stake/{user}'
  _globals['_QUERY'].methods_by_name['GetIon']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetIon']._serialized_options = b'\202\323\344\223\002 \022\036/neurion/ganglion/get_ion/{id}'
  _globals['_QUERY'].methods_by_name['GetPathwayUnstakeInitiatedUsers']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetPathwayUnstakeInitiatedUsers']._serialized_options = b'\202\323\344\223\0027\0225/neurion/ganglion/get_pathway_unstake_initiated_users'
  _globals['_QUERY'].methods_by_name['GetStakerReward']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetStakerReward']._serialized_options = b'\202\323\344\223\002%\022#/neurion/ganglion/get_staker_reward'
  _globals['_QUERY'].methods_by_name['GetAvailableIons']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetAvailableIons']._serialized_options = b'\202\323\344\223\002>\022</neurion/ganglion/get_available_ions/{user}/{offset}/{limit}'
  _globals['_QUERY'].methods_by_name['ValidateIonChain']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ValidateIonChain']._serialized_options = b'\202\323\344\223\002G\022E/neurion/ganglion/validate_ion_chain/{ion1}/{ion2}/{field_map_base64}'
  _globals['_QUERY'].methods_by_name['GetAllowedIps']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetAllowedIps']._serialized_options = b'\202\323\344\223\002#\022!/neurion/ganglion/get_allowed_ips'
  _globals['_QUERYPARAMSREQUEST']._serialized_start=293
  _globals['_QUERYPARAMSREQUEST']._serialized_end=313
  _globals['_QUERYPARAMSRESPONSE']._serialized_start=315
  _globals['_QUERYPARAMSRESPONSE']._serialized_end=389
  _globals['_QUERYIONBYIONADDRESSREQUEST']._serialized_start=391
  _globals['_QUERYIONBYIONADDRESSREQUEST']._serialized_end=441
  _globals['_QUERYIONBYIONADDRESSRESPONSE']._serialized_start=443
  _globals['_QUERYIONBYIONADDRESSRESPONSE']._serialized_end=509
  _globals['_QUERYIONBYCREATORREQUEST']._serialized_start=511
  _globals['_QUERYIONBYCREATORREQUEST']._serialized_end=554
  _globals['_QUERYIONBYCREATORRESPONSE']._serialized_start=556
  _globals['_QUERYIONBYCREATORRESPONSE']._serialized_end=619
  _globals['_QUERYGETVALIDATORSREQUEST']._serialized_start=621
  _globals['_QUERYGETVALIDATORSREQUEST']._serialized_end=648
  _globals['_QUERYGETVALIDATORSRESPONSE']._serialized_start=650
  _globals['_QUERYGETVALIDATORSRESPONSE']._serialized_end=698
  _globals['_QUERYIONSBYINPUTSCHEMAHASHREQUEST']._serialized_start=700
  _globals['_QUERYIONSBYINPUTSCHEMAHASHREQUEST']._serialized_end=807
  _globals['_QUERYIONSBYINPUTSCHEMAHASHRESPONSE']._serialized_start=810
  _globals['_QUERYIONSBYINPUTSCHEMAHASHRESPONSE']._serialized_end=955
  _globals['_QUERYGETPATHWAYREQUEST']._serialized_start=957
  _globals['_QUERYGETPATHWAYREQUEST']._serialized_end=993
  _globals['_QUERYGETPATHWAYRESPONSE']._serialized_start=995
  _globals['_QUERYGETPATHWAYRESPONSE']._serialized_end=1075
  _globals['_QUERYLISTPATHWAYSREQUEST']._serialized_start=1077
  _globals['_QUERYLISTPATHWAYSREQUEST']._serialized_end=1151
  _globals['_QUERYLISTPATHWAYSRESPONSE']._serialized_start=1154
  _globals['_QUERYLISTPATHWAYSRESPONSE']._serialized_end=1298
  _globals['_QUERYLISTIONSBYADDRESSESREQUEST']._serialized_start=1300
  _globals['_QUERYLISTIONSBYADDRESSESREQUEST']._serialized_end=1356
  _globals['_QUERYLISTIONSBYADDRESSESRESPONSE']._serialized_start=1358
  _globals['_QUERYLISTIONSBYADDRESSESRESPONSE']._serialized_end=1440
  _globals['_QUERYUSERPATHWAYSTAKEREQUEST']._serialized_start=1442
  _globals['_QUERYUSERPATHWAYSTAKEREQUEST']._serialized_end=1498
  _globals['_QUERYUSERPATHWAYSTAKERESPONSE']._serialized_start=1500
  _globals['_QUERYUSERPATHWAYSTAKERESPONSE']._serialized_end=1546
  _globals['_QUERYGETUSERREWARDREQUEST']._serialized_start=1548
  _globals['_QUERYGETUSERREWARDREQUEST']._serialized_end=1589
  _globals['_QUERYGETUSERREWARDRESPONSE']._serialized_start=1591
  _globals['_QUERYGETUSERREWARDRESPONSE']._serialized_end=1635
  _globals['_QUERYGETPROTOCOLFEEREQUEST']._serialized_start=1637
  _globals['_QUERYGETPROTOCOLFEEREQUEST']._serialized_end=1665
  _globals['_QUERYGETPROTOCOLFEERESPONSE']._serialized_start=1667
  _globals['_QUERYGETPROTOCOLFEERESPONSE']._serialized_end=1709
  _globals['_QUERYPATHWAYSUSINGIONREQUEST']._serialized_start=1711
  _globals['_QUERYPATHWAYSUSINGIONREQUEST']._serialized_end=1762
  _globals['_QUERYPATHWAYSUSINGIONRESPONSE']._serialized_start=1764
  _globals['_QUERYPATHWAYSUSINGIONRESPONSE']._serialized_end=1851
  _globals['_QUERYIONSBYREPORTSREQUEST']._serialized_start=1853
  _globals['_QUERYIONSBYREPORTSREQUEST']._serialized_end=1911
  _globals['_QUERYIONSBYREPORTSRESPONSE']._serialized_start=1913
  _globals['_QUERYIONSBYREPORTSRESPONSE']._serialized_end=2025
  _globals['_QUERYLISTALLPATHWAYSREQUEST']._serialized_start=2027
  _globals['_QUERYLISTALLPATHWAYSREQUEST']._serialized_end=2087
  _globals['_QUERYLISTALLPATHWAYSRESPONSE']._serialized_start=2090
  _globals['_QUERYLISTALLPATHWAYSRESPONSE']._serialized_end=2237
  _globals['_QUERYGETREWARDREQUEST']._serialized_start=2239
  _globals['_QUERYGETREWARDREQUEST']._serialized_end=2276
  _globals['_QUERYGETREWARDRESPONSE']._serialized_start=2278
  _globals['_QUERYGETREWARDRESPONSE']._serialized_end=2318
  _globals['_QUERYGETSTAKEREQUEST']._serialized_start=2320
  _globals['_QUERYGETSTAKEREQUEST']._serialized_end=2356
  _globals['_QUERYGETSTAKERESPONSE']._serialized_start=2358
  _globals['_QUERYGETSTAKERESPONSE']._serialized_end=2396
  _globals['_QUERYGETIONREQUEST']._serialized_start=2398
  _globals['_QUERYGETIONREQUEST']._serialized_end=2430
  _globals['_QUERYGETIONRESPONSE']._serialized_start=2432
  _globals['_QUERYGETIONRESPONSE']._serialized_end=2500
  _globals['_QUERYGETPATHWAYUNSTAKEINITIATEDUSERSREQUEST']._serialized_start=2502
  _globals['_QUERYGETPATHWAYUNSTAKEINITIATEDUSERSREQUEST']._serialized_end=2547
  _globals['_QUERYGETPATHWAYUNSTAKEINITIATEDUSERSRESPONSE']._serialized_start=2549
  _globals['_QUERYGETPATHWAYUNSTAKEINITIATEDUSERSRESPONSE']._serialized_end=2660
  _globals['_QUERYGETSTAKERREWARDREQUEST']._serialized_start=2662
  _globals['_QUERYGETSTAKERREWARDREQUEST']._serialized_end=2691
  _globals['_QUERYGETSTAKERREWARDRESPONSE']._serialized_start=2693
  _globals['_QUERYGETSTAKERREWARDRESPONSE']._serialized_end=2739
  _globals['_QUERYGETAVAILABLEIONSREQUEST']._serialized_start=2741
  _globals['_QUERYGETAVAILABLEIONSREQUEST']._serialized_end=2816
  _globals['_QUERYGETAVAILABLEIONSRESPONSE']._serialized_start=2819
  _globals['_QUERYGETAVAILABLEIONSRESPONSE']._serialized_end=2959
  _globals['_QUERYVALIDATEIONCHAINREQUEST']._serialized_start=2961
  _globals['_QUERYVALIDATEIONCHAINREQUEST']._serialized_end=3045
  _globals['_QUERYVALIDATEIONCHAINRESPONSE']._serialized_start=3047
  _globals['_QUERYVALIDATEIONCHAINRESPONSE']._serialized_end=3109
  _globals['_QUERYGETALLOWEDIPSREQUEST']._serialized_start=3111
  _globals['_QUERYGETALLOWEDIPSREQUEST']._serialized_end=3138
  _globals['_QUERYGETALLOWEDIPSRESPONSE']._serialized_start=3140
  _globals['_QUERYGETALLOWEDIPSRESPONSE']._serialized_end=3181
  _globals['_QUERY']._serialized_start=3184
  _globals['_QUERY']._serialized_end=6882
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tendermint/p2p/pex.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'tendermint/p2p/pex.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from tendermint.p2p import types_pb2 as tendermint_dot_p2p_dot_types__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18tendermint/p2p/pex.proto\x12\x0etendermint.p2p\x1a\x1atendermint/p2p/types.proto\x1a\x14gogoproto/gogo.proto\"\x0c\n\nPexRequest\";\n\x08PexAddrs\x12/\n\x05\x61\x64\x64rs\x18\x01 \x03(\x0b\x32\x1a.tendermint.p2p.NetAddressB\x04\xc8\xde\x1f\x00\"r\n\x07Message\x12\x31\n\x0bpex_request\x18\x01 \x01(\x0b\x32\x1a.tendermint.p2p.PexRequestH\x00\x12-\n\tpex_addrs\x18\x02 \x01(\x0b\x32\x18.tendermint.p2p.PexAddrsH\x00\x42\x05\n\x03sumB7Z5github.com/tendermint/tendermint/proto/tendermint/p2pb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tendermint.p2p.pex_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z5github.com/tendermint/tendermint/proto/tendermint/p2p'
  _globals['_PEXADDRS'].fields_by_name['addrs']._loaded_options = None
  _globals['_PEXADDRS'].fields_by_name['addrs']._serialized_options = b'\310\336\037\000'
  _globals['_PEXREQUEST']._serialized_start=94
  _globals['_PEXREQUEST']._serialized_end=106
  _globals['_PEXADDRS']._serialized_start=108
  _globals['_PEXADDRS']._serialized_end=167
  _globals['_MESSAGE']._serialized_start=169
  _globals['_MESSAGE']._serialized_end=283
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ibc/applications/interchain_accounts/controller/v1/query.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'ibc/applications/interchain_accounts/controller/v1/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ibc.applications.interchain_accounts.controller.v1 import controller_pb2 as ibc_dot_applications_dot_interchain__accounts_dot_controller_dot_v1_dot_controller__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>ibc/applications/interchain_accounts/controller/v1/query.proto\x12\x32ibc.applications.interchain_accounts.controller.v1\x1a\x43ibc/applications/interchain_accounts/controller/v1/controller.proto\x1a\x1cgoogle/api/annotations.proto\"\x14\n\x12QueryParamsRequest\"a\n\x13QueryParamsResponse\x12J\n\x06params\x18\x01 \x01(\x0b\x32:.ibc.applications.interchain_accounts.controller.v1.Params2\xdf\x01\n\x05Query\x12\xd5\x01\n\x06Params\x12\x46.ibc.applications.interchain_accounts.controller.v1.QueryParamsRequest\x1aG.ibc.applications.interchain_accounts.controller.v1.QueryParamsResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/ibc/apps/interchain_accounts/controller/v1/paramsBRZPgithub.com/cosmos/ibc-go/v3/modules/apps/27-interchain-accounts/controller/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.applications.interchain_accounts.controller.v1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZPgithub.com/cosmos/ibc-go/v3/modules/apps/27-interchain-accounts/controller/types'
  _globals['_QUERY'].methods_by_name['Params']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Params']._serialized_options = b'\202\323\344\223\0024\0222/ibc/apps/interchain_accounts/controller/v1/params'
  _globals['_QUERYPARAMSREQUEST']._serialized_start=217
  _globals['_QUERYPARAMSREQUEST']._serialized_end=237
  _globals['_QUERYPARAMSRESPONSE']._serialized_start=239
  _globals['_QUERYPARAMSRESPONSE']._serialized_end=336
  _globals['_QUERY']._serialized_start=339
  _globals['_QUERY']._serialized_end=562
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/distribution/v1beta1/tx.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cosmos/distribution/v1beta1/tx.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$cosmos/distribution/v1beta1/tx.proto\x12\x1b\x63osmos.distribution.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"\x91\x01\n\x15MsgSetWithdrawAddress\x12\x37\n\x11\x64\x65legator_address\x18\x01 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:\"delegator_address\"\x12\x35\n\x10withdraw_address\x18\x02 \x01(\tB\x1b\xf2\xde\x1f\x17yaml:\"withdraw_address\":\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\x1f\n\x1dMsgSetWithdrawAddressResponse\"\x98\x01\n\x1aMsgWithdrawDelegatorReward\x12\x37\n\x11\x64\x65legator_address\x18\x01 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:\"delegator_address\"\x12\x37\n\x11validator_address\x18\x02 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:\"validator_address\":\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"$\n\"MsgWithdrawDelegatorRewardResponse\"c\n\x1eMsgWithdrawValidatorCommission\x12\x37\n\x11validator_address\x18\x01 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:\"validator_address\":\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"(\n&MsgWithdrawValidatorCommissionResponse\"\x90\x01\n\x14MsgFundCommunityPool\x12[\n\x06\x61mount\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12\x11\n\tdepositor\x18\x02 \x01(\t:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\x1e\n\x1cMsgFundCommunityPoolResponse2\xc8\x04\n\x03Msg\x12\x84\x01\n\x12SetWithdrawAddress\x12\x32.cosmos.distribution.v1beta1.MsgSetWithdrawAddress\x1a:.cosmos.distribution.v1beta1.MsgSetWithdrawAddressResponse\x12\x93\x01\n\x17WithdrawDelegatorReward\x12\x37.cosmos.distribution.v1beta1.MsgWithdrawDelegatorReward\x1a?.cosmos.distribution.v1beta1.MsgWithdrawDelegatorRewardResponse\x12\x9f\x01\n\x1bWithdrawValidatorCommission\x12;.cosmos.distribution.v1beta1.MsgWithdrawValidatorCommission\x1a\x43.cosmos.distribution.v1beta1.MsgWithdrawValidatorCommissionResponse\x12\x81\x01\n\x11\x46undCommunityPool\x12\x31.cosmos.distribution.v1beta1.MsgFundCommunityPool\x1a\x39.cosmos.distribution.v1beta1.MsgFundCommunityPoolResponseB7Z1github.com/cosmos/cosmos-sdk/x/distribution/types\xa8\xe2\x1e\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.distribution.v1beta1.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/cosmos/cosmos-sdk/x/distribution/types\250\342\036\001'
  _globals['_MSGSETWITHDRAWADDRESS'].fields_by_name['delegator_address']._loaded_options = None
  _globals['_MSGSETWITHDRAWADDRESS'].fields_by_name['delegator_address']._serialized_options = b'\362\336\037\030yaml:\"delegator_address\"'
  _globals['_MSGSETWITHDRAWADDRESS'].fields_by_name['withdraw_address']._loaded_options = None
  _globals['_MSGSETWITHDRAWADDRESS'].fields_by_name['withdraw_address']._serialized_options = b'\362\336\037\027yaml:\"withdraw_address\"'
  _globals['_MSGSETWITHDRAWADDRESS']._loaded_options = None
  _globals['_MSGSETWITHDRAWADDRESS']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_MSGWITHDRAWDELEGATORREWARD'].fields_by_name['delegator_address']._loaded_options = None
  _globals['_MSGWITHDRAWDELEGATORREWARD'].fields_by_name['delegator_address']._serialized_options = b'\362\336\037\030yaml:\"delegator_address\"'
  _globals['_MSGWITHDRAWDELEGATORREWARD'].fields_by_name['validator_address']._loaded_options = None
  _globals['_MSGWITHDRAWDELEGATORREWARD'].fields_by_name['validator_address']._serialized_options = b'\362\336\037\030yaml:\"validator_address\"'
  _globals['_MSGWITHDRAWDELEGATORREWARD']._loaded_options = None
  _globals['_MSGWITHDRAWDELEGATORREWARD']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_MSGWITHDRAWVALIDATORCOMMISSION'].fields_by_name['validator_address']._loaded_options = None
  _globals['_MSGWITHDRAWVALIDATORCOMMISSION'].fields_by_name['validator_address']._serialized_options = b'\362\336\037\030yaml:\"validator_address\"'
  _globals['_MSGWITHDRAWVALIDATORCOMMISSION']._loaded_options = None
  _globals['_MSGWITHDRAWVALIDATORCOMMISSION']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_MSGFUNDCOMMUNITYPOOL'].fields_by_name['amount']._loaded_options = None
  _globals['_MSGFUNDCOMMUNITYPOOL'].fields_by_name['amount']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _globals['_MSGFUNDCOMMUNITYPOOL']._loaded_options = None
  _globals['_MSGFUNDCOMMUNITYPOOL']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_MSGSETWITHDRAWADDRESS']._serialized_start=124
  _globals['_MSGSETWITHDRAWADDRESS']._serialized_end=269
  _globals['_MSGSETWITHDRAWADDRESSRESPONSE']._serialized_start=271
  _globals['_MSGSETWITHDRAWADDRESSRESPONSE']._serialized_end=302
  _globals['_MSGWITHDRAWDELEGATORREWARD']._serialized_start=305
  _globals['_MSGWITHDRAWDELEGATORREWARD']._serialized_end=457
  _globals['_MSGWITHDRAWDELEGATORREWARDRESPONSE']._serialized_start=459
  _globals['_MSGWITHDRAWDELEGATORREWARDRESPONSE']._serialized_end=495
  _globals['_MSGWITHDRAWVALIDATORCOMMISSION']._serialized_start=497
  _globals['_MSGWITHDRAWVALIDATORCOMMISSION']._serialized_end=596
  _globals['_MSGWITHDRAWVALIDATORCOMMISSIONRESPONSE']._serialized_start=598
  _globals['_MSGWITHDRAWVALIDATORCOMMISSIONRESPONSE']._serialized_end=638
  _globals['_MSGFUNDCOMMUNITYPOOL']._serialized_start=641
  _globals['_MSGFUNDCOMMUNITYPOOL']._serialized_end=785
  _globals['_MSGFUNDCOMMUNITYPOOLRESPONSE']._serialized_start=787
  _globals['_MSGFUNDCOMMUNITYPOOLRESPONSE']._serialized_end=817
  _globals['_MSG']._serialized_start=820
  _globals['_MSG']._serialized_end=1404
# @@protoc_insertion_point(module_scope)



from dataclasses import dataclass
from datetime import datetime, timedelta, timezone
from typing import Any, Dict, List, Optional, Tuple
from google.protobuf.timestamp_pb2 import Timestamp
from neurionpy.synapse.client.staking import (
    ValidatorStatus,
)
from neurionpy.crypto.address import Address
from neurionpy.crypto.hashfuncs import sha256
from neurionpy.protos.cosmos.crypto.ed25519.keys_pb2 import (  # noqa # pylint: disable=unused-import
    PubKey,
)



DEFAULT_QUERY_TIMEOUT_SECS = 15
DEFAULT_QUERY_INTERVAL_SECS = 2
COSMOS_SDK_DEC_COIN_PRECISION = 10 ** 18


@dataclass
class Account:
    """Account."""

    address: Address
    number: int
    sequence: int


@dataclass
class StakingPosition:
    """Staking positions."""

    validator: Address
    amount: int
    reward: int


@dataclass
class UnbondingPositions:
    """Unbonding positions."""

    validator: Address
    amount: int


@dataclass
class Validator:
    """Validator."""

    address: Address  # the operators address
    tokens: int  # The total amount of tokens for the validator
    moniker: str
    status: ValidatorStatus


@dataclass
class Coin:
    """Coins."""

    amount: int
    denom: str


@dataclass
class StakingSummary:
    """Get the staking summary."""

    current_positions: List[StakingPosition]
    unbonding_positions: List[UnbondingPositions]

    @property
    def total_staked(self) -> int:
        """Get the total staked amount."""
        return sum(map(lambda p: p.amount, self.current_positions))

    @property
    def total_rewards(self) -> int:
        """Get the total rewards."""
        return sum(map(lambda p: p.reward, self.current_positions))

    @property
    def total_unbonding(self) -> int:
        """total unbonding."""
        return sum(map(lambda p: p.amount, self.unbonding_positions))


@dataclass
class Block:
    """Block."""

    height: int
    time: datetime
    chain_id: str
    tx_hashes: List[str]

    @staticmethod
    def from_proto(block: Any) -> "Block":
        """Parse the block.

        :param block: block as Any
        :return: parsed block as Block
        """
        return Block(
            height=int(block.header.height),
            time=Block._parse_timestamp(block.header.time),
            tx_hashes=[sha256(tx).hex().upper() for tx in block.data.txs],
            chain_id=block.header.chain_id,
        )

    @staticmethod
    def _parse_timestamp(timestamp: Timestamp):
        """Parse the timestamp.

        :param timestamp: timestamp
        :return: parsed timestamp
        """
        return datetime.fromtimestamp(timestamp.seconds, tz=timezone.utc) + timedelta(
            microseconds=timestamp.nanos // 1000
        )




# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ibc/lightclients/solomachine/v1/solomachine.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'ibc/lightclients/solomachine/v1/solomachine.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ibc.core.connection.v1 import connection_pb2 as ibc_dot_core_dot_connection_dot_v1_dot_connection__pb2
from ibc.core.channel.v1 import channel_pb2 as ibc_dot_core_dot_channel_dot_v1_dot_channel__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1ibc/lightclients/solomachine/v1/solomachine.proto\x12\x1fibc.lightclients.solomachine.v1\x1a\'ibc/core/connection/v1/connection.proto\x1a!ibc/core/channel/v1/channel.proto\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\"\x8d\x02\n\x0b\x43lientState\x12\x10\n\x08sequence\x18\x01 \x01(\x04\x12\x33\n\x0f\x66rozen_sequence\x18\x02 \x01(\x04\x42\x1a\xf2\xde\x1f\x16yaml:\"frozen_sequence\"\x12\x64\n\x0f\x63onsensus_state\x18\x03 \x01(\x0b\x32/.ibc.lightclients.solomachine.v1.ConsensusStateB\x1a\xf2\xde\x1f\x16yaml:\"consensus_state\"\x12K\n\x1b\x61llow_update_after_proposal\x18\x04 \x01(\x08\x42&\xf2\xde\x1f\"yaml:\"allow_update_after_proposal\":\x04\x88\xa0\x1f\x00\"\x7f\n\x0e\x43onsensusState\x12?\n\npublic_key\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyB\x15\xf2\xde\x1f\x11yaml:\"public_key\"\x12\x13\n\x0b\x64iversifier\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x04:\x04\x88\xa0\x1f\x00\"\xc4\x01\n\x06Header\x12\x10\n\x08sequence\x18\x01 \x01(\x04\x12\x11\n\ttimestamp\x18\x02 \x01(\x04\x12\x11\n\tsignature\x18\x03 \x01(\x0c\x12G\n\x0enew_public_key\x18\x04 \x01(\x0b\x32\x14.google.protobuf.AnyB\x19\xf2\xde\x1f\x15yaml:\"new_public_key\"\x12\x33\n\x0fnew_diversifier\x18\x05 \x01(\tB\x1a\xf2\xde\x1f\x16yaml:\"new_diversifier\":\x04\x88\xa0\x1f\x00\"\x97\x02\n\x0cMisbehaviour\x12\'\n\tclient_id\x18\x01 \x01(\tB\x14\xf2\xde\x1f\x10yaml:\"client_id\"\x12\x10\n\x08sequence\x18\x02 \x01(\x04\x12\x62\n\rsignature_one\x18\x03 \x01(\x0b\x32\x31.ibc.lightclients.solomachine.v1.SignatureAndDataB\x18\xf2\xde\x1f\x14yaml:\"signature_one\"\x12\x62\n\rsignature_two\x18\x04 \x01(\x0b\x32\x31.ibc.lightclients.solomachine.v1.SignatureAndDataB\x18\xf2\xde\x1f\x14yaml:\"signature_two\":\x04\x88\xa0\x1f\x00\"\xa0\x01\n\x10SignatureAndData\x12\x11\n\tsignature\x18\x01 \x01(\x0c\x12R\n\tdata_type\x18\x02 \x01(\x0e\x32).ibc.lightclients.solomachine.v1.DataTypeB\x14\xf2\xde\x1f\x10yaml:\"data_type\"\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\x12\x11\n\ttimestamp\x18\x04 \x01(\x04:\x04\x88\xa0\x1f\x00\"f\n\x18TimestampedSignatureData\x12\x31\n\x0esignature_data\x18\x01 \x01(\x0c\x42\x19\xf2\xde\x1f\x15yaml:\"signature_data\"\x12\x11\n\ttimestamp\x18\x02 \x01(\x04:\x04\x88\xa0\x1f\x00\"\xad\x01\n\tSignBytes\x12\x10\n\x08sequence\x18\x01 \x01(\x04\x12\x11\n\ttimestamp\x18\x02 \x01(\x04\x12\x13\n\x0b\x64iversifier\x18\x03 \x01(\t\x12R\n\tdata_type\x18\x04 \x01(\x0e\x32).ibc.lightclients.solomachine.v1.DataTypeB\x14\xf2\xde\x1f\x10yaml:\"data_type\"\x12\x0c\n\x04\x64\x61ta\x18\x05 \x01(\x0c:\x04\x88\xa0\x1f\x00\"\x8a\x01\n\nHeaderData\x12\x41\n\x0bnew_pub_key\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyB\x16\xf2\xde\x1f\x12yaml:\"new_pub_key\"\x12\x33\n\x0fnew_diversifier\x18\x02 \x01(\tB\x1a\xf2\xde\x1f\x16yaml:\"new_diversifier\":\x04\x88\xa0\x1f\x00\"j\n\x0f\x43lientStateData\x12\x0c\n\x04path\x18\x01 \x01(\x0c\x12\x43\n\x0c\x63lient_state\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyB\x17\xf2\xde\x1f\x13yaml:\"client_state\":\x04\x88\xa0\x1f\x00\"s\n\x12\x43onsensusStateData\x12\x0c\n\x04path\x18\x01 \x01(\x0c\x12I\n\x0f\x63onsensus_state\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyB\x1a\xf2\xde\x1f\x16yaml:\"consensus_state\":\x04\x88\xa0\x1f\x00\"d\n\x13\x43onnectionStateData\x12\x0c\n\x04path\x18\x01 \x01(\x0c\x12\x39\n\nconnection\x18\x02 \x01(\x0b\x32%.ibc.core.connection.v1.ConnectionEnd:\x04\x88\xa0\x1f\x00\"U\n\x10\x43hannelStateData\x12\x0c\n\x04path\x18\x01 \x01(\x0c\x12-\n\x07\x63hannel\x18\x02 \x01(\x0b\x32\x1c.ibc.core.channel.v1.Channel:\x04\x88\xa0\x1f\x00\"8\n\x14PacketCommitmentData\x12\x0c\n\x04path\x18\x01 \x01(\x0c\x12\x12\n\ncommitment\x18\x02 \x01(\x0c\"B\n\x19PacketAcknowledgementData\x12\x0c\n\x04path\x18\x01 \x01(\x0c\x12\x17\n\x0f\x61\x63knowledgement\x18\x02 \x01(\x0c\"(\n\x18PacketReceiptAbsenceData\x12\x0c\n\x04path\x18\x01 \x01(\x0c\"U\n\x14NextSequenceRecvData\x12\x0c\n\x04path\x18\x01 \x01(\x0c\x12/\n\rnext_seq_recv\x18\x02 \x01(\x04\x42\x18\xf2\xde\x1f\x14yaml:\"next_seq_recv\"*\x8c\x04\n\x08\x44\x61taType\x12\x38\n#DATA_TYPE_UNINITIALIZED_UNSPECIFIED\x10\x00\x1a\x0f\x8a\x9d \x0bUNSPECIFIED\x12&\n\x16\x44\x41TA_TYPE_CLIENT_STATE\x10\x01\x1a\n\x8a\x9d \x06\x43LIENT\x12,\n\x19\x44\x41TA_TYPE_CONSENSUS_STATE\x10\x02\x1a\r\x8a\x9d \tCONSENSUS\x12.\n\x1a\x44\x41TA_TYPE_CONNECTION_STATE\x10\x03\x1a\x0e\x8a\x9d \nCONNECTION\x12(\n\x17\x44\x41TA_TYPE_CHANNEL_STATE\x10\x04\x1a\x0b\x8a\x9d \x07\x43HANNEL\x12\x35\n\x1b\x44\x41TA_TYPE_PACKET_COMMITMENT\x10\x05\x1a\x14\x8a\x9d \x10PACKETCOMMITMENT\x12?\n DATA_TYPE_PACKET_ACKNOWLEDGEMENT\x10\x06\x1a\x19\x8a\x9d \x15PACKETACKNOWLEDGEMENT\x12>\n DATA_TYPE_PACKET_RECEIPT_ABSENCE\x10\x07\x1a\x18\x8a\x9d \x14PACKETRECEIPTABSENCE\x12\x36\n\x1c\x44\x41TA_TYPE_NEXT_SEQUENCE_RECV\x10\x08\x1a\x14\x8a\x9d \x10NEXTSEQUENCERECV\x12 \n\x10\x44\x41TA_TYPE_HEADER\x10\t\x1a\n\x8a\x9d \x06HEADER\x1a\x04\x88\xa3\x1e\x00\x42@Z>github.com/cosmos/ibc-go/v2/modules/core/02-client/legacy/v100b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.lightclients.solomachine.v1.solomachine_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z>github.com/cosmos/ibc-go/v2/modules/core/02-client/legacy/v100'
  _globals['_DATATYPE']._loaded_options = None
  _globals['_DATATYPE']._serialized_options = b'\210\243\036\000'
  _globals['_DATATYPE'].values_by_name["DATA_TYPE_UNINITIALIZED_UNSPECIFIED"]._loaded_options = None
  _globals['_DATATYPE'].values_by_name["DATA_TYPE_UNINITIALIZED_UNSPECIFIED"]._serialized_options = b'\212\235 \013UNSPECIFIED'
  _globals['_DATATYPE'].values_by_name["DATA_TYPE_CLIENT_STATE"]._loaded_options = None
  _globals['_DATATYPE'].values_by_name["DATA_TYPE_CLIENT_STATE"]._serialized_options = b'\212\235 \006CLIENT'
  _globals['_DATATYPE'].values_by_name["DATA_TYPE_CONSENSUS_STATE"]._loaded_options = None
  _globals['_DATATYPE'].values_by_name["DATA_TYPE_CONSENSUS_STATE"]._serialized_options = b'\212\235 \tCONSENSUS'
  _globals['_DATATYPE'].values_by_name["DATA_TYPE_CONNECTION_STATE"]._loaded_options = None
  _globals['_DATATYPE'].values_by_name["DATA_TYPE_CONNECTION_STATE"]._serialized_options = b'\212\235 \nCONNECTION'
  _globals['_DATATYPE'].values_by_name["DATA_TYPE_CHANNEL_STATE"]._loaded_options = None
  _globals['_DATATYPE'].values_by_name["DATA_TYPE_CHANNEL_STATE"]._serialized_options = b'\212\235 \007CHANNEL'
  _globals['_DATATYPE'].values_by_name["DATA_TYPE_PACKET_COMMITMENT"]._loaded_options = None
  _globals['_DATATYPE'].values_by_name["DATA_TYPE_PACKET_COMMITMENT"]._serialized_options = b'\212\235 \020PACKETCOMMITMENT'
  _globals['_DATATYPE'].values_by_name["DATA_TYPE_PACKET_ACKNOWLEDGEMENT"]._loaded_options = None
  _globals['_DATATYPE'].values_by_name["DATA_TYPE_PACKET_ACKNOWLEDGEMENT"]._serialized_options = b'\212\235 \025PACKETACKNOWLEDGEMENT'
  _globals['_DATATYPE'].values_by_name["DATA_TYPE_PACKET_RECEIPT_ABSENCE"]._loaded_options = None
  _globals['_DATATYPE'].values_by_name["DATA_TYPE_PACKET_RECEIPT_ABSENCE"]._serialized_options = b'\212\235 \024PACKETRECEIPTABSENCE'
  _globals['_DATATYPE'].values_by_name["DATA_TYPE_NEXT_SEQUENCE_RECV"]._loaded_options = None
  _globals['_DATATYPE'].values_by_name["DATA_TYPE_NEXT_SEQUENCE_RECV"]._serialized_options = b'\212\235 \020NEXTSEQUENCERECV'
  _globals['_DATATYPE'].values_by_name["DATA_TYPE_HEADER"]._loaded_options = None
  _globals['_DATATYPE'].values_by_name["DATA_TYPE_HEADER"]._serialized_options = b'\212\235 \006HEADER'
  _globals['_CLIENTSTATE'].fields_by_name['frozen_sequence']._loaded_options = None
  _globals['_CLIENTSTATE'].fields_by_name['frozen_sequence']._serialized_options = b'\362\336\037\026yaml:\"frozen_sequence\"'
  _globals['_CLIENTSTATE'].fields_by_name['consensus_state']._loaded_options = None
  _globals['_CLIENTSTATE'].fields_by_name['consensus_state']._serialized_options = b'\362\336\037\026yaml:\"consensus_state\"'
  _globals['_CLIENTSTATE'].fields_by_name['allow_update_after_proposal']._loaded_options = None
  _globals['_CLIENTSTATE'].fields_by_name['allow_update_after_proposal']._serialized_options = b'\362\336\037\"yaml:\"allow_update_after_proposal\"'
  _globals['_CLIENTSTATE']._loaded_options = None
  _globals['_CLIENTSTATE']._serialized_options = b'\210\240\037\000'
  _globals['_CONSENSUSSTATE'].fields_by_name['public_key']._loaded_options = None
  _globals['_CONSENSUSSTATE'].fields_by_name['public_key']._serialized_options = b'\362\336\037\021yaml:\"public_key\"'
  _globals['_CONSENSUSSTATE']._loaded_options = None
  _globals['_CONSENSUSSTATE']._serialized_options = b'\210\240\037\000'
  _globals['_HEADER'].fields_by_name['new_public_key']._loaded_options = None
  _globals['_HEADER'].fields_by_name['new_public_key']._serialized_options = b'\362\336\037\025yaml:\"new_public_key\"'
  _globals['_HEADER'].fields_by_name['new_diversifier']._loaded_options = None
  _globals['_HEADER'].fields_by_name['new_diversifier']._serialized_options = b'\362\336\037\026yaml:\"new_diversifier\"'
  _globals['_HEADER']._loaded_options = None
  _globals['_HEADER']._serialized_options = b'\210\240\037\000'
  _globals['_MISBEHAVIOUR'].fields_by_name['client_id']._loaded_options = None
  _globals['_MISBEHAVIOUR'].fields_by_name['client_id']._serialized_options = b'\362\336\037\020yaml:\"client_id\"'
  _globals['_MISBEHAVIOUR'].fields_by_name['signature_one']._loaded_options = None
  _globals['_MISBEHAVIOUR'].fields_by_name['signature_one']._serialized_options = b'\362\336\037\024yaml:\"signature_one\"'
  _globals['_MISBEHAVIOUR'].fields_by_name['signature_two']._loaded_options = None
  _globals['_MISBEHAVIOUR'].fields_by_name['signature_two']._serialized_options = b'\362\336\037\024yaml:\"signature_two\"'
  _globals['_MISBEHAVIOUR']._loaded_options = None
  _globals['_MISBEHAVIOUR']._serialized_options = b'\210\240\037\000'
  _globals['_SIGNATUREANDDATA'].fields_by_name['data_type']._loaded_options = None
  _globals['_SIGNATUREANDDATA'].fields_by_name['data_type']._serialized_options = b'\362\336\037\020yaml:\"data_type\"'
  _globals['_SIGNATUREANDDATA']._loaded_options = None
  _globals['_SIGNATUREANDDATA']._serialized_options = b'\210\240\037\000'
  _globals['_TIMESTAMPEDSIGNATUREDATA'].fields_by_name['signature_data']._loaded_options = None
  _globals['_TIMESTAMPEDSIGNATUREDATA'].fields_by_name['signature_data']._serialized_options = b'\362\336\037\025yaml:\"signature_data\"'
  _globals['_TIMESTAMPEDSIGNATUREDATA']._loaded_options = None
  _globals['_TIMESTAMPEDSIGNATUREDATA']._serialized_options = b'\210\240\037\000'
  _globals['_SIGNBYTES'].fields_by_name['data_type']._loaded_options = None
  _globals['_SIGNBYTES'].fields_by_name['data_type']._serialized_options = b'\362\336\037\020yaml:\"data_type\"'
  _globals['_SIGNBYTES']._loaded_options = None
  _globals['_SIGNBYTES']._serialized_options = b'\210\240\037\000'
  _globals['_HEADERDATA'].fields_by_name['new_pub_key']._loaded_options = None
  _globals['_HEADERDATA'].fields_by_name['new_pub_key']._serialized_options = b'\362\336\037\022yaml:\"new_pub_key\"'
  _globals['_HEADERDATA'].fields_by_name['new_diversifier']._loaded_options = None
  _globals['_HEADERDATA'].fields_by_name['new_diversifier']._serialized_options = b'\362\336\037\026yaml:\"new_diversifier\"'
  _globals['_HEADERDATA']._loaded_options = None
  _globals['_HEADERDATA']._serialized_options = b'\210\240\037\000'
  _globals['_CLIENTSTATEDATA'].fields_by_name['client_state']._loaded_options = None
  _globals['_CLIENTSTATEDATA'].fields_by_name['client_state']._serialized_options = b'\362\336\037\023yaml:\"client_state\"'
  _globals['_CLIENTSTATEDATA']._loaded_options = None
  _globals['_CLIENTSTATEDATA']._serialized_options = b'\210\240\037\000'
  _globals['_CONSENSUSSTATEDATA'].fields_by_name['consensus_state']._loaded_options = None
  _globals['_CONSENSUSSTATEDATA'].fields_by_name['consensus_state']._serialized_options = b'\362\336\037\026yaml:\"consensus_state\"'
  _globals['_CONSENSUSSTATEDATA']._loaded_options = None
  _globals['_CONSENSUSSTATEDATA']._serialized_options = b'\210\240\037\000'
  _globals['_CONNECTIONSTATEDATA']._loaded_options = None
  _globals['_CONNECTIONSTATEDATA']._serialized_options = b'\210\240\037\000'
  _globals['_CHANNELSTATEDATA']._loaded_options = None
  _globals['_CHANNELSTATEDATA']._serialized_options = b'\210\240\037\000'
  _globals['_NEXTSEQUENCERECVDATA'].fields_by_name['next_seq_recv']._loaded_options = None
  _globals['_NEXTSEQUENCERECVDATA'].fields_by_name['next_seq_recv']._serialized_options = b'\362\336\037\024yaml:\"next_seq_recv\"'
  _globals['_DATATYPE']._serialized_start=2347
  _globals['_DATATYPE']._serialized_end=2871
  _globals['_CLIENTSTATE']._serialized_start=212
  _globals['_CLIENTSTATE']._serialized_end=481
  _globals['_CONSENSUSSTATE']._serialized_start=483
  _globals['_CONSENSUSSTATE']._serialized_end=610
  _globals['_HEADER']._serialized_start=613
  _globals['_HEADER']._serialized_end=809
  _globals['_MISBEHAVIOUR']._serialized_start=812
  _globals['_MISBEHAVIOUR']._serialized_end=1091
  _globals['_SIGNATUREANDDATA']._serialized_start=1094
  _globals['_SIGNATUREANDDATA']._serialized_end=1254
  _globals['_TIMESTAMPEDSIGNATUREDATA']._serialized_start=1256
  _globals['_TIMESTAMPEDSIGNATUREDATA']._serialized_end=1358
  _globals['_SIGNBYTES']._serialized_start=1361
  _globals['_SIGNBYTES']._serialized_end=1534
  _globals['_HEADERDATA']._serialized_start=1537
  _globals['_HEADERDATA']._serialized_end=1675
  _globals['_CLIENTSTATEDATA']._serialized_start=1677
  _globals['_CLIENTSTATEDATA']._serialized_end=1783
  _globals['_CONSENSUSSTATEDATA']._serialized_start=1785
  _globals['_CONSENSUSSTATEDATA']._serialized_end=1900
  _globals['_CONNECTIONSTATEDATA']._serialized_start=1902
  _globals['_CONNECTIONSTATEDATA']._serialized_end=2002
  _globals['_CHANNELSTATEDATA']._serialized_start=2004
  _globals['_CHANNELSTATEDATA']._serialized_end=2089
  _globals['_PACKETCOMMITMENTDATA']._serialized_start=2091
  _globals['_PACKETCOMMITMENTDATA']._serialized_end=2147
  _globals['_PACKETACKNOWLEDGEMENTDATA']._serialized_start=2149
  _globals['_PACKETACKNOWLEDGEMENTDATA']._serialized_end=2215
  _globals['_PACKETRECEIPTABSENCEDATA']._serialized_start=2217
  _globals['_PACKETRECEIPTABSENCEDATA']._serialized_end=2257
  _globals['_NEXTSEQUENCERECVDATA']._serialized_start=2259
  _globals['_NEXTSEQUENCERECVDATA']._serialized_end=2344
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: neurion/crucible/task.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'neurion/crucible/task.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bneurion/crucible/task.proto\x12\x10neurion.crucible\"\xb9\x03\n\x04Task\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x0f\n\x07\x63reator\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x0e\n\x06reward\x18\x05 \x01(\x04\x12\x18\n\x10\x64uration_in_days\x18\x06 \x01(\x04\x12\x14\n\x0ctraining_kit\x18\x07 \x01(\t\x12\x16\n\x0evalidation_kit\x18\x08 \x01(\t\x12\x16\n\x0e\x66inal_test_kit\x18\t \x01(\t\x12,\n\x06status\x18\n \x01(\x0e\x32\x1c.neurion.crucible.TaskStatus\x12\x19\n\x11\x63reated_timestamp\x18\x0b \x01(\x04\x12\x19\n\x11started_timestamp\x18\x0c \x01(\x04\x12\x1c\n\x14terminated_timestamp\x18\r \x01(\x04\x12\"\n\x1a\x66inal_submission_timestamp\x18\x0e \x01(\x04\x12\x1f\n\x17\x66inal_testing_timestamp\x18\x0f \x01(\x04\x12\x1f\n\x17\x66inal_dispute_timestamp\x18\x10 \x01(\x04\x12\x19\n\x11\x61\x62orted_timestamp\x18\x11 \x01(\x04*\xd3\x01\n\nTaskStatus\x12\x17\n\x13TASK_STATUS_CREATED\x10\x00\x12\x17\n\x13TASK_STATUS_STARTED\x10\x01\x12\x17\n\x13TASK_STATUS_ABORTED\x10\x02\x12 \n\x1cTASK_STATUS_FINAL_SUBMISSION\x10\x04\x12\x1d\n\x19TASK_STATUS_FINAL_TESTING\x10\x05\x12\x1d\n\x19TASK_STATUS_FINAL_DISPUTE\x10\x06\x12\x1a\n\x16TASK_STATUS_TERMINATED\x10\x07\x42\x1aZ\x18neurion/x/crucible/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'neurion.crucible.task_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\030neurion/x/crucible/types'
  _globals['_TASKSTATUS']._serialized_start=494
  _globals['_TASKSTATUS']._serialized_end=705
  _globals['_TASK']._serialized_start=50
  _globals['_TASK']._serialized_end=491
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor_pb2 as _descriptor_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ScalarType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    SCALAR_TYPE_UNSPECIFIED: _ClassVar[ScalarType]
    SCALAR_TYPE_STRING: _ClassVar[ScalarType]
    SCALAR_TYPE_BYTES: _ClassVar[ScalarType]
SCALAR_TYPE_UNSPECIFIED: ScalarType
SCALAR_TYPE_STRING: ScalarType
SCALAR_TYPE_BYTES: ScalarType
METHOD_ADDED_IN_FIELD_NUMBER: _ClassVar[int]
method_added_in: _descriptor.FieldDescriptor
IMPLEMENTS_INTERFACE_FIELD_NUMBER: _ClassVar[int]
implements_interface: _descriptor.FieldDescriptor
MESSAGE_ADDED_IN_FIELD_NUMBER: _ClassVar[int]
message_added_in: _descriptor.FieldDescriptor
ACCEPTS_INTERFACE_FIELD_NUMBER: _ClassVar[int]
accepts_interface: _descriptor.FieldDescriptor
SCALAR_FIELD_NUMBER: _ClassVar[int]
scalar: _descriptor.FieldDescriptor
FIELD_ADDED_IN_FIELD_NUMBER: _ClassVar[int]
field_added_in: _descriptor.FieldDescriptor
DECLARE_INTERFACE_FIELD_NUMBER: _ClassVar[int]
declare_interface: _descriptor.FieldDescriptor
DECLARE_SCALAR_FIELD_NUMBER: _ClassVar[int]
declare_scalar: _descriptor.FieldDescriptor
FILE_ADDED_IN_FIELD_NUMBER: _ClassVar[int]
file_added_in: _descriptor.FieldDescriptor

class InterfaceDescriptor(_message.Message):
    __slots__ = ("name", "description")
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    name: str
    description: str
    def __init__(self, name: _Optional[str] = ..., description: _Optional[str] = ...) -> None: ...

class ScalarDescriptor(_message.Message):
    __slots__ = ("name", "description", "field_type")
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    FIELD_TYPE_FIELD_NUMBER: _ClassVar[int]
    name: str
    description: str
    field_type: _containers.RepeatedScalarFieldContainer[ScalarType]
    def __init__(self, name: _Optional[str] = ..., description: _Optional[str] = ..., field_type: _Optional[_Iterable[_Union[ScalarType, str]]] = ...) -> None: ...



from abc import ABC, abstractmethod

from neurionpy.protos.cosmos.gov.v1beta1.query_pb2 import (
    QueryDepositRequest,
    QueryDepositResponse,
    QueryDepositsRequest,
    QueryDepositsResponse,
    QueryParamsRequest,
    QueryParamsResponse,
    QueryProposalRequest,
    QueryProposalResponse,
    QueryProposalsRequest,
    QueryProposalsResponse,
    QueryTallyResultRequest,
    QueryTallyResultResponse,
    QueryVoteRequest,
    QueryVoteResponse,
    QueryVotesRequest,
    QueryVotesResponse,
)


class Gov(ABC):
    """Gov abstract class."""

    @abstractmethod
    def Proposal(self, request: QueryProposalRequest) -> QueryProposalResponse:
        """
        Proposal queries proposal details based on ProposalID.

        :param request: QueryProposalRequest with proposal id

        :return: QueryProposalResponse
        """

    @abstractmethod
    def Proposals(self, request: QueryProposalsRequest) -> QueryProposalsResponse:
        """
        Proposals queries all proposals based on given status.

        :param request: QueryProposalsRequest

        :return: QueryProposalsResponse
        """

    @abstractmethod
    def Vote(self, request: QueryVoteRequest) -> QueryVoteResponse:
        """
        Vote queries voted information based on proposalID, voterAddr.

        :param request: QueryVoteRequest with voter and proposal id

        :return: QueryVoteResponse
        """

    @abstractmethod
    def Votes(self, request: QueryVotesRequest) -> QueryVotesResponse:
        """
        Votes queries votes of a given proposal.

        :param request: QueryVotesResponse with proposal id

        :return: QueryVotesResponse
        """

    @abstractmethod
    def Params(self, request: QueryParamsRequest) -> QueryParamsResponse:
        """
        Params queries all parameters of the gov module.

        :param request: QueryParamsRequest with params_type

        :return: QueryParamsResponse
        """

    @abstractmethod
    def Deposit(self, request: QueryDepositRequest) -> QueryDepositResponse:
        """
        Deposit queries single deposit information based proposalID, depositAddr.

        :param request: QueryDepositRequest with depositor and proposal_id

        :return: QueryDepositResponse
        """

    @abstractmethod
    def Deposits(self, request: QueryDepositsRequest) -> QueryDepositsResponse:
        """Deposits queries all deposits of a single proposal.

        :param request: QueryDepositsRequest with proposal_id

        :return: QueryDepositsResponse
        """

    @abstractmethod
    def TallyResult(self, request: QueryTallyResultRequest) -> QueryTallyResultResponse:
        """
        Tally Result queries the tally of a proposal vote.

        :param request: QueryTallyResultRequest with proposal_id

        :return: QueryTallyResultResponse
        """



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class StoreKVPair(_message.Message):
    __slots__ = ("store_key", "delete", "key", "value")
    STORE_KEY_FIELD_NUMBER: _ClassVar[int]
    DELETE_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    store_key: str
    delete: bool
    key: bytes
    value: bytes
    def __init__(self, store_key: _Optional[str] = ..., delete: bool = ..., key: _Optional[bytes] = ..., value: _Optional[bytes] = ...) -> None: ...



from gogoproto import gogo_pb2 as _gogo_pb2
from tendermint.consensus import types_pb2 as _types_pb2
from tendermint.types import events_pb2 as _events_pb2
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MsgInfo(_message.Message):
    __slots__ = ("msg", "peer_id")
    MSG_FIELD_NUMBER: _ClassVar[int]
    PEER_ID_FIELD_NUMBER: _ClassVar[int]
    msg: _types_pb2.Message
    peer_id: str
    def __init__(self, msg: _Optional[_Union[_types_pb2.Message, _Mapping]] = ..., peer_id: _Optional[str] = ...) -> None: ...

class TimeoutInfo(_message.Message):
    __slots__ = ("duration", "height", "round", "step")
    DURATION_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    ROUND_FIELD_NUMBER: _ClassVar[int]
    STEP_FIELD_NUMBER: _ClassVar[int]
    duration: _duration_pb2.Duration
    height: int
    round: int
    step: int
    def __init__(self, duration: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., height: _Optional[int] = ..., round: _Optional[int] = ..., step: _Optional[int] = ...) -> None: ...

class EndHeight(_message.Message):
    __slots__ = ("height",)
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    height: int
    def __init__(self, height: _Optional[int] = ...) -> None: ...

class WALMessage(_message.Message):
    __slots__ = ("event_data_round_state", "msg_info", "timeout_info", "end_height")
    EVENT_DATA_ROUND_STATE_FIELD_NUMBER: _ClassVar[int]
    MSG_INFO_FIELD_NUMBER: _ClassVar[int]
    TIMEOUT_INFO_FIELD_NUMBER: _ClassVar[int]
    END_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    event_data_round_state: _events_pb2.EventDataRoundState
    msg_info: MsgInfo
    timeout_info: TimeoutInfo
    end_height: EndHeight
    def __init__(self, event_data_round_state: _Optional[_Union[_events_pb2.EventDataRoundState, _Mapping]] = ..., msg_info: _Optional[_Union[MsgInfo, _Mapping]] = ..., timeout_info: _Optional[_Union[TimeoutInfo, _Mapping]] = ..., end_height: _Optional[_Union[EndHeight, _Mapping]] = ...) -> None: ...

class TimedWALMessage(_message.Message):
    __slots__ = ("time", "msg")
    TIME_FIELD_NUMBER: _ClassVar[int]
    MSG_FIELD_NUMBER: _ClassVar[int]
    time: _timestamp_pb2.Timestamp
    msg: WALMessage
    def __init__(self, time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., msg: _Optional[_Union[WALMessage, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cometbft/services/block_results/v1/block_results_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cometbft/services/block_results/v1/block_results_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cometbft.services.block_results.v1 import block_results_pb2 as cometbft_dot_services_dot_block__results_dot_v1_dot_block__results__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>cometbft/services/block_results/v1/block_results_service.proto\x12\"cometbft.services.block_results.v1\x1a\x36\x63ometbft/services/block_results/v1/block_results.proto2\xa2\x01\n\x13\x42lockResultsService\x12\x8a\x01\n\x0fGetBlockResults\x12:.cometbft.services.block_results.v1.GetBlockResultsRequest\x1a;.cometbft.services.block_results.v1.GetBlockResultsResponseBEZCgithub.com/cometbft/cometbft/api/cometbft/services/block_results/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.services.block_results.v1.block_results_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZCgithub.com/cometbft/cometbft/api/cometbft/services/block_results/v1'
  _globals['_BLOCKRESULTSSERVICE']._serialized_start=159
  _globals['_BLOCKRESULTSSERVICE']._serialized_end=321
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ibc/core/connection/v1/query.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'ibc/core/connection/v1/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from ibc.core.client.v1 import client_pb2 as ibc_dot_core_dot_client_dot_v1_dot_client__pb2
from ibc.core.connection.v1 import connection_pb2 as ibc_dot_core_dot_connection_dot_v1_dot_connection__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"ibc/core/connection/v1/query.proto\x12\x16ibc.core.connection.v1\x1a\x14gogoproto/gogo.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x1fibc/core/client/v1/client.proto\x1a\'ibc/core/connection/v1/connection.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x19google/protobuf/any.proto\"/\n\x16QueryConnectionRequest\x12\x15\n\rconnection_id\x18\x01 \x01(\t\"\x9b\x01\n\x17QueryConnectionResponse\x12\x39\n\nconnection\x18\x01 \x01(\x0b\x32%.ibc.core.connection.v1.ConnectionEnd\x12\r\n\x05proof\x18\x02 \x01(\x0c\x12\x36\n\x0cproof_height\x18\x03 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00\"U\n\x17QueryConnectionsRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\xcc\x01\n\x18QueryConnectionsResponse\x12\x41\n\x0b\x63onnections\x18\x01 \x03(\x0b\x32,.ibc.core.connection.v1.IdentifiedConnection\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\x12\x30\n\x06height\x18\x03 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00\"2\n\x1dQueryClientConnectionsRequest\x12\x11\n\tclient_id\x18\x01 \x01(\t\"\x81\x01\n\x1eQueryClientConnectionsResponse\x12\x18\n\x10\x63onnection_paths\x18\x01 \x03(\t\x12\r\n\x05proof\x18\x02 \x01(\x0c\x12\x36\n\x0cproof_height\x18\x03 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00\"T\n!QueryConnectionClientStateRequest\x12/\n\rconnection_id\x18\x01 \x01(\tB\x18\xf2\xde\x1f\x14yaml:\"connection_id\"\"\xb7\x01\n\"QueryConnectionClientStateResponse\x12J\n\x17identified_client_state\x18\x01 \x01(\x0b\x32).ibc.core.client.v1.IdentifiedClientState\x12\r\n\x05proof\x18\x02 \x01(\x0c\x12\x36\n\x0cproof_height\x18\x03 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00\"\x89\x01\n$QueryConnectionConsensusStateRequest\x12/\n\rconnection_id\x18\x01 \x01(\tB\x18\xf2\xde\x1f\x14yaml:\"connection_id\"\x12\x17\n\x0frevision_number\x18\x02 \x01(\x04\x12\x17\n\x0frevision_height\x18\x03 \x01(\x04\"\xb0\x01\n%QueryConnectionConsensusStateResponse\x12-\n\x0f\x63onsensus_state\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x11\n\tclient_id\x18\x02 \x01(\t\x12\r\n\x05proof\x18\x03 \x01(\x0c\x12\x36\n\x0cproof_height\x18\x04 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00\x32\x8f\x08\n\x05Query\x12\xaa\x01\n\nConnection\x12..ibc.core.connection.v1.QueryConnectionRequest\x1a/.ibc.core.connection.v1.QueryConnectionResponse\";\x82\xd3\xe4\x93\x02\x35\x12\x33/ibc/core/connection/v1/connections/{connection_id}\x12\x9d\x01\n\x0b\x43onnections\x12/.ibc.core.connection.v1.QueryConnectionsRequest\x1a\x30.ibc.core.connection.v1.QueryConnectionsResponse\"+\x82\xd3\xe4\x93\x02%\x12#/ibc/core/connection/v1/connections\x12\xc2\x01\n\x11\x43lientConnections\x12\x35.ibc.core.connection.v1.QueryClientConnectionsRequest\x1a\x36.ibc.core.connection.v1.QueryClientConnectionsResponse\">\x82\xd3\xe4\x93\x02\x38\x12\x36/ibc/core/connection/v1/client_connections/{client_id}\x12\xd8\x01\n\x15\x43onnectionClientState\x12\x39.ibc.core.connection.v1.QueryConnectionClientStateRequest\x1a:.ibc.core.connection.v1.QueryConnectionClientStateResponse\"H\x82\xd3\xe4\x93\x02\x42\x12@/ibc/core/connection/v1/connections/{connection_id}/client_state\x12\x98\x02\n\x18\x43onnectionConsensusState\x12<.ibc.core.connection.v1.QueryConnectionConsensusStateRequest\x1a=.ibc.core.connection.v1.QueryConnectionConsensusStateResponse\"\x7f\x82\xd3\xe4\x93\x02y\x12w/ibc/core/connection/v1/connections/{connection_id}/consensus_state/revision/{revision_number}/height/{revision_height}B>Z<github.com/cosmos/ibc-go/v2/modules/core/03-connection/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.core.connection.v1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z<github.com/cosmos/ibc-go/v2/modules/core/03-connection/types'
  _globals['_QUERYCONNECTIONRESPONSE'].fields_by_name['proof_height']._loaded_options = None
  _globals['_QUERYCONNECTIONRESPONSE'].fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYCONNECTIONSRESPONSE'].fields_by_name['height']._loaded_options = None
  _globals['_QUERYCONNECTIONSRESPONSE'].fields_by_name['height']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYCLIENTCONNECTIONSRESPONSE'].fields_by_name['proof_height']._loaded_options = None
  _globals['_QUERYCLIENTCONNECTIONSRESPONSE'].fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYCONNECTIONCLIENTSTATEREQUEST'].fields_by_name['connection_id']._loaded_options = None
  _globals['_QUERYCONNECTIONCLIENTSTATEREQUEST'].fields_by_name['connection_id']._serialized_options = b'\362\336\037\024yaml:\"connection_id\"'
  _globals['_QUERYCONNECTIONCLIENTSTATERESPONSE'].fields_by_name['proof_height']._loaded_options = None
  _globals['_QUERYCONNECTIONCLIENTSTATERESPONSE'].fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYCONNECTIONCONSENSUSSTATEREQUEST'].fields_by_name['connection_id']._loaded_options = None
  _globals['_QUERYCONNECTIONCONSENSUSSTATEREQUEST'].fields_by_name['connection_id']._serialized_options = b'\362\336\037\024yaml:\"connection_id\"'
  _globals['_QUERYCONNECTIONCONSENSUSSTATERESPONSE'].fields_by_name['proof_height']._loaded_options = None
  _globals['_QUERYCONNECTIONCONSENSUSSTATERESPONSE'].fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _globals['_QUERY'].methods_by_name['Connection']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Connection']._serialized_options = b'\202\323\344\223\0025\0223/ibc/core/connection/v1/connections/{connection_id}'
  _globals['_QUERY'].methods_by_name['Connections']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Connections']._serialized_options = b'\202\323\344\223\002%\022#/ibc/core/connection/v1/connections'
  _globals['_QUERY'].methods_by_name['ClientConnections']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ClientConnections']._serialized_options = b'\202\323\344\223\0028\0226/ibc/core/connection/v1/client_connections/{client_id}'
  _globals['_QUERY'].methods_by_name['ConnectionClientState']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ConnectionClientState']._serialized_options = b'\202\323\344\223\002B\022@/ibc/core/connection/v1/connections/{connection_id}/client_state'
  _globals['_QUERY'].methods_by_name['ConnectionConsensusState']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ConnectionConsensusState']._serialized_options = b'\202\323\344\223\002y\022w/ibc/core/connection/v1/connections/{connection_id}/consensus_state/revision/{revision_number}/height/{revision_height}'
  _globals['_QUERYCONNECTIONREQUEST']._serialized_start=259
  _globals['_QUERYCONNECTIONREQUEST']._serialized_end=306
  _globals['_QUERYCONNECTIONRESPONSE']._serialized_start=309
  _globals['_QUERYCONNECTIONRESPONSE']._serialized_end=464
  _globals['_QUERYCONNECTIONSREQUEST']._serialized_start=466
  _globals['_QUERYCONNECTIONSREQUEST']._serialized_end=551
  _globals['_QUERYCONNECTIONSRESPONSE']._serialized_start=554
  _globals['_QUERYCONNECTIONSRESPONSE']._serialized_end=758
  _globals['_QUERYCLIENTCONNECTIONSREQUEST']._serialized_start=760
  _globals['_QUERYCLIENTCONNECTIONSREQUEST']._serialized_end=810
  _globals['_QUERYCLIENTCONNECTIONSRESPONSE']._serialized_start=813
  _globals['_QUERYCLIENTCONNECTIONSRESPONSE']._serialized_end=942
  _globals['_QUERYCONNECTIONCLIENTSTATEREQUEST']._serialized_start=944
  _globals['_QUERYCONNECTIONCLIENTSTATEREQUEST']._serialized_end=1028
  _globals['_QUERYCONNECTIONCLIENTSTATERESPONSE']._serialized_start=1031
  _globals['_QUERYCONNECTIONCLIENTSTATERESPONSE']._serialized_end=1214
  _globals['_QUERYCONNECTIONCONSENSUSSTATEREQUEST']._serialized_start=1217
  _globals['_QUERYCONNECTIONCONSENSUSSTATEREQUEST']._serialized_end=1354
  _globals['_QUERYCONNECTIONCONSENSUSSTATERESPONSE']._serialized_start=1357
  _globals['_QUERYCONNECTIONCONSENSUSSTATERESPONSE']._serialized_end=1533
  _globals['_QUERY']._serialized_start=1536
  _globals['_QUERY']._serialized_end=2575
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cometbft/types/v2/params.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cometbft/types/v2/params.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x63ometbft/types/v2/params.proto\x12\x11\x63ometbft.types.v2\x1a\x14gogoproto/gogo.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\xfa\x02\n\x0f\x43onsensusParams\x12-\n\x05\x62lock\x18\x01 \x01(\x0b\x32\x1e.cometbft.types.v2.BlockParams\x12\x33\n\x08\x65vidence\x18\x02 \x01(\x0b\x32!.cometbft.types.v2.EvidenceParams\x12\x35\n\tvalidator\x18\x03 \x01(\x0b\x32\".cometbft.types.v2.ValidatorParams\x12\x31\n\x07version\x18\x04 \x01(\x0b\x32 .cometbft.types.v2.VersionParams\x12/\n\x04\x61\x62\x63i\x18\x05 \x01(\x0b\x32\x1d.cometbft.types.v2.ABCIParamsB\x02\x18\x01\x12\x35\n\tsynchrony\x18\x06 \x01(\x0b\x32\".cometbft.types.v2.SynchronyParams\x12\x31\n\x07\x66\x65\x61ture\x18\x07 \x01(\x0b\x32 .cometbft.types.v2.FeatureParams\"7\n\x0b\x42lockParams\x12\x11\n\tmax_bytes\x18\x01 \x01(\x03\x12\x0f\n\x07max_gas\x18\x02 \x01(\x03J\x04\x08\x03\x10\x04\"~\n\x0e\x45videnceParams\x12\x1a\n\x12max_age_num_blocks\x18\x01 \x01(\x03\x12=\n\x10max_age_duration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xc8\xde\x1f\x00\x98\xdf\x1f\x01\x12\x11\n\tmax_bytes\x18\x03 \x01(\x03\"2\n\x0fValidatorParams\x12\x15\n\rpub_key_types\x18\x01 \x03(\t:\x08\xb8\xa0\x1f\x01\xe8\xa0\x1f\x01\"&\n\rVersionParams\x12\x0b\n\x03\x61pp\x18\x01 \x01(\x04:\x08\xb8\xa0\x1f\x01\xe8\xa0\x1f\x01\">\n\x0cHashedParams\x12\x17\n\x0f\x62lock_max_bytes\x18\x01 \x01(\x03\x12\x15\n\rblock_max_gas\x18\x02 \x01(\x03\"}\n\x0fSynchronyParams\x12\x32\n\tprecision\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\x04\x98\xdf\x1f\x01\x12\x36\n\rmessage_delay\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x04\x98\xdf\x1f\x01\"\x98\x01\n\rFeatureParams\x12H\n\x1dvote_extensions_enable_height\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x04\xc8\xde\x1f\x01\x12=\n\x12pbts_enable_height\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x04\xc8\xde\x1f\x01\"7\n\nABCIParams\x12%\n\x1dvote_extensions_enable_height\x18\x01 \x01(\x03:\x02\x18\x01\x42\x38Z2github.com/cometbft/cometbft/api/cometbft/types/v2\xa8\xe2\x1e\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.types.v2.params_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z2github.com/cometbft/cometbft/api/cometbft/types/v2\250\342\036\001'
  _globals['_CONSENSUSPARAMS'].fields_by_name['abci']._loaded_options = None
  _globals['_CONSENSUSPARAMS'].fields_by_name['abci']._serialized_options = b'\030\001'
  _globals['_EVIDENCEPARAMS'].fields_by_name['max_age_duration']._loaded_options = None
  _globals['_EVIDENCEPARAMS'].fields_by_name['max_age_duration']._serialized_options = b'\310\336\037\000\230\337\037\001'
  _globals['_VALIDATORPARAMS']._loaded_options = None
  _globals['_VALIDATORPARAMS']._serialized_options = b'\270\240\037\001\350\240\037\001'
  _globals['_VERSIONPARAMS']._loaded_options = None
  _globals['_VERSIONPARAMS']._serialized_options = b'\270\240\037\001\350\240\037\001'
  _globals['_SYNCHRONYPARAMS'].fields_by_name['precision']._loaded_options = None
  _globals['_SYNCHRONYPARAMS'].fields_by_name['precision']._serialized_options = b'\230\337\037\001'
  _globals['_SYNCHRONYPARAMS'].fields_by_name['message_delay']._loaded_options = None
  _globals['_SYNCHRONYPARAMS'].fields_by_name['message_delay']._serialized_options = b'\230\337\037\001'
  _globals['_FEATUREPARAMS'].fields_by_name['vote_extensions_enable_height']._loaded_options = None
  _globals['_FEATUREPARAMS'].fields_by_name['vote_extensions_enable_height']._serialized_options = b'\310\336\037\001'
  _globals['_FEATUREPARAMS'].fields_by_name['pbts_enable_height']._loaded_options = None
  _globals['_FEATUREPARAMS'].fields_by_name['pbts_enable_height']._serialized_options = b'\310\336\037\001'
  _globals['_ABCIPARAMS']._loaded_options = None
  _globals['_ABCIPARAMS']._serialized_options = b'\030\001'
  _globals['_CONSENSUSPARAMS']._serialized_start=140
  _globals['_CONSENSUSPARAMS']._serialized_end=518
  _globals['_BLOCKPARAMS']._serialized_start=520
  _globals['_BLOCKPARAMS']._serialized_end=575
  _globals['_EVIDENCEPARAMS']._serialized_start=577
  _globals['_EVIDENCEPARAMS']._serialized_end=703
  _globals['_VALIDATORPARAMS']._serialized_start=705
  _globals['_VALIDATORPARAMS']._serialized_end=755
  _globals['_VERSIONPARAMS']._serialized_start=757
  _globals['_VERSIONPARAMS']._serialized_end=795
  _globals['_HASHEDPARAMS']._serialized_start=797
  _globals['_HASHEDPARAMS']._serialized_end=859
  _globals['_SYNCHRONYPARAMS']._serialized_start=861
  _globals['_SYNCHRONYPARAMS']._serialized_end=986
  _globals['_FEATUREPARAMS']._serialized_start=989
  _globals['_FEATUREPARAMS']._serialized_end=1141
  _globals['_ABCIPARAMS']._serialized_start=1143
  _globals['_ABCIPARAMS']._serialized_end=1198
# @@protoc_insertion_point(module_scope)



from gogoproto import gogo_pb2 as _gogo_pb2
from ibc.core.commitment.v1 import commitment_pb2 as _commitment_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class State(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    STATE_UNINITIALIZED_UNSPECIFIED: _ClassVar[State]
    STATE_INIT: _ClassVar[State]
    STATE_TRYOPEN: _ClassVar[State]
    STATE_OPEN: _ClassVar[State]
STATE_UNINITIALIZED_UNSPECIFIED: State
STATE_INIT: State
STATE_TRYOPEN: State
STATE_OPEN: State

class ConnectionEnd(_message.Message):
    __slots__ = ("client_id", "versions", "state", "counterparty", "delay_period")
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    VERSIONS_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    COUNTERPARTY_FIELD_NUMBER: _ClassVar[int]
    DELAY_PERIOD_FIELD_NUMBER: _ClassVar[int]
    client_id: str
    versions: _containers.RepeatedCompositeFieldContainer[Version]
    state: State
    counterparty: Counterparty
    delay_period: int
    def __init__(self, client_id: _Optional[str] = ..., versions: _Optional[_Iterable[_Union[Version, _Mapping]]] = ..., state: _Optional[_Union[State, str]] = ..., counterparty: _Optional[_Union[Counterparty, _Mapping]] = ..., delay_period: _Optional[int] = ...) -> None: ...

class IdentifiedConnection(_message.Message):
    __slots__ = ("id", "client_id", "versions", "state", "counterparty", "delay_period")
    ID_FIELD_NUMBER: _ClassVar[int]
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    VERSIONS_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    COUNTERPARTY_FIELD_NUMBER: _ClassVar[int]
    DELAY_PERIOD_FIELD_NUMBER: _ClassVar[int]
    id: str
    client_id: str
    versions: _containers.RepeatedCompositeFieldContainer[Version]
    state: State
    counterparty: Counterparty
    delay_period: int
    def __init__(self, id: _Optional[str] = ..., client_id: _Optional[str] = ..., versions: _Optional[_Iterable[_Union[Version, _Mapping]]] = ..., state: _Optional[_Union[State, str]] = ..., counterparty: _Optional[_Union[Counterparty, _Mapping]] = ..., delay_period: _Optional[int] = ...) -> None: ...

class Counterparty(_message.Message):
    __slots__ = ("client_id", "connection_id", "prefix")
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    CONNECTION_ID_FIELD_NUMBER: _ClassVar[int]
    PREFIX_FIELD_NUMBER: _ClassVar[int]
    client_id: str
    connection_id: str
    prefix: _commitment_pb2.MerklePrefix
    def __init__(self, client_id: _Optional[str] = ..., connection_id: _Optional[str] = ..., prefix: _Optional[_Union[_commitment_pb2.MerklePrefix, _Mapping]] = ...) -> None: ...

class ClientPaths(_message.Message):
    __slots__ = ("paths",)
    PATHS_FIELD_NUMBER: _ClassVar[int]
    paths: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, paths: _Optional[_Iterable[str]] = ...) -> None: ...

class ConnectionPaths(_message.Message):
    __slots__ = ("client_id", "paths")
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    PATHS_FIELD_NUMBER: _ClassVar[int]
    client_id: str
    paths: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, client_id: _Optional[str] = ..., paths: _Optional[_Iterable[str]] = ...) -> None: ...

class Version(_message.Message):
    __slots__ = ("identifier", "features")
    IDENTIFIER_FIELD_NUMBER: _ClassVar[int]
    FEATURES_FIELD_NUMBER: _ClassVar[int]
    identifier: str
    features: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, identifier: _Optional[str] = ..., features: _Optional[_Iterable[str]] = ...) -> None: ...

class Params(_message.Message):
    __slots__ = ("max_expected_time_per_block",)
    MAX_EXPECTED_TIME_PER_BLOCK_FIELD_NUMBER: _ClassVar[int]
    max_expected_time_per_block: int
    def __init__(self, max_expected_time_per_block: _Optional[int] = ...) -> None: ...



from typing import Any, Dict, List, Optional, Union


Primitive = Union[str, int, bool, float]
_JSONDict = Dict[Any, Any]  # temporary placeholder
_JSONList = List[Any]  # temporary placeholder
_JSONType = Optional[Union[Primitive, _JSONDict, _JSONList]]
# Added Dict[str, _JSONDict] as workaround to not properly resolving recursive types - _JSONDict should be subset of _JSONType
JSONLike = Union[Dict[str, _JSONType], Dict[str, _JSONDict]]



from ibc.applications.interchain_accounts.controller.v1 import controller_pb2 as _controller_pb2
from google.api import annotations_pb2 as _annotations_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class QueryParamsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class QueryParamsResponse(_message.Message):
    __slots__ = ("params",)
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    params: _controller_pb2.Params
    def __init__(self, params: _Optional[_Union[_controller_pb2.Params, _Mapping]] = ...) -> None: ...



from google.protobuf import any_pb2 as _any_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Type(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    TYPE_UNSPECIFIED: _ClassVar[Type]
    TYPE_EXECUTE_TX: _ClassVar[Type]
TYPE_UNSPECIFIED: Type
TYPE_EXECUTE_TX: Type

class InterchainAccountPacketData(_message.Message):
    __slots__ = ("type", "data", "memo")
    TYPE_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    MEMO_FIELD_NUMBER: _ClassVar[int]
    type: Type
    data: bytes
    memo: str
    def __init__(self, type: _Optional[_Union[Type, str]] = ..., data: _Optional[bytes] = ..., memo: _Optional[str] = ...) -> None: ...

class CosmosTx(_message.Message):
    __slots__ = ("messages",)
    MESSAGES_FIELD_NUMBER: _ClassVar[int]
    messages: _containers.RepeatedCompositeFieldContainer[_any_pb2.Any]
    def __init__(self, messages: _Optional[_Iterable[_Union[_any_pb2.Any, _Mapping]]] = ...) -> None: ...
